@@ -50,6 +50,9 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <stdlib.h>
 #include <assert.h>
 #include <string.h>
+#ifdef HAVE_UCRED_H
+#include <ucred.h>
+#endif /* HAVE_UCRED_H */
 
 #include <tqguardedptr.h>
 #include <tqtextstream.h>
@@ -724,7 +727,7 @@ bool DCOPClient::isSuspended() const
     return !d->notifier->isEnabled();
 }
 
-#if defined(SO_PEERCRED) || defined(LOCAL_PEEREID)
+#if defined(SO_PEERCRED) || defined(LOCAL_PEEREID) || defined(HAVE_GETPEERUCRED)
 #define USE_PEER_IS_US
 // Check whether the remote end is owned by the same user.
 static bool peerIsUs(int sockfd)
@@ -745,6 +748,18 @@ static bool peerIsUs(int sockfd)
     if (getsockopt(sockfd, 0, LOCAL_PEEREID, &cred, &siz) != 0 || siz != sizeof(cred))
         return false;
     return (cred.unp_euid == geteuid());
+#elif defined(HAVE_GETPEERUCRED)
+    ucred_t *cred = nullptr;
+    uint_t peer_uid;
+
+    if (getpeerucred(sockfd, &cred) != 0) {
+        if (cred != nullptr)
+            ucred_free(cred);
+        return false;
+    }
+    peer_uid = ucred_geteuid(cred);
+    ucred_free(cred);
+    return (peer_uid == getuid());
 #endif
 }
 #else
@@ -806,7 +821,7 @@ bool DCOPClient::attachInternal( bool registerAsAnonymous )
                 emit attachFailed(TQString::fromLatin1( "Could not read network connection list.\n" )+TQFile::decodeName(fName));
                 return false;
             }
-            int size = TQMIN( (qint64)1024, f.size() ); // protection against a huge file
+            int size = TQMIN( (long)1024, f.size() ); // protection against a huge file
             TQCString contents( size+1 );
             if ( f.readBlock( contents.data(), size ) != size )
             {
@@ -1497,7 +1512,7 @@ static bool receiveQtObject( const TQCString &objId, const TQCString &fun, const
             TQStrList lst = o->metaObject()->slotNames( true );
             int i = 0;
             for ( TQPtrListIterator<char> it( lst ); it.current(); ++it ) {
-                if ( o->metaObject()->slot( i++, true )->tqt_mo_access != TQMetaData::Public )
+                if ( o->metaObject()->slot( i++, true )->access != TQMetaData::Public )
                     continue;
                 TQCString slot = it.current();
                 if ( slot.contains( "()" ) ) {
