@@ -550,7 +550,7 @@ public:
 class QConfigDB : public TQWidget
 {
   // ############################################################################
-  Q_OBJECT
+  TQ_OBJECT
   // ----------------------------------------------------------------------------
 protected:
   /**
