@@ -92,7 +92,7 @@ class KateSchemaManager
 
 class KateViewSchemaAction : public TDEActionMenu
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
     KateViewSchemaAction(const TQString& text, TQObject* parent = 0, const char* name = 0)
@@ -127,7 +127,7 @@ class KateViewSchemaAction : public TDEActionMenu
 */
 class KateStyleListView : public TQListView
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   friend class KateStyleListItem;
 
@@ -162,7 +162,7 @@ class KateStyleListView : public TQListView
 
 class KateSchemaConfigColorTab : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
     KateSchemaConfigColorTab( TQWidget *parent = 0, const char *name = 0 );
@@ -209,7 +209,7 @@ typedef TQMap<int,TQFont> FontMap; // ### remove it
 
 class KateSchemaConfigFontTab : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
     KateSchemaConfigFontTab( TQWidget *parent = 0, const char *name = 0 );
@@ -236,7 +236,7 @@ class KateSchemaConfigFontTab : public TQWidget
 
 class KateSchemaConfigFontColorTab : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
     KateSchemaConfigFontColorTab( TQWidget *parent = 0, const char *name = 0 );
@@ -256,7 +256,7 @@ class KateSchemaConfigFontColorTab : public TQWidget
 
 class KateSchemaConfigHighlightTab : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
     KateSchemaConfigHighlightTab( TQWidget *parent = 0, const char *name = 0, KateSchemaConfigFontColorTab *page = 0, uint hl = 0 );
@@ -284,7 +284,7 @@ class KateSchemaConfigHighlightTab : public TQWidget
 
 class KateSchemaConfigPage : public KateConfigPage
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
     KateSchemaConfigPage ( TQWidget *parent, class KateDocument *doc=0 );
