@@ -131,7 +131,7 @@ KateView::KateView( KateDocument *doc, TQWidget *parent, const char * name )
   doc->addView( this );
 
   setFocusProxy( m_viewInternal );
-  setFocusPolicy( TQ_StrongFocus );
+  setFocusPolicy( TQWidget::StrongFocus );
 
   if (!doc->singleViewMode()) {
     setXMLFile( "katepartui.rc" );
