@@ -709,7 +709,7 @@ static TDECmdLineOptions options[] = {
 static const char appName[] = "tdebuildsycoca";
 static const char appVersion[] = "1.1";
 
-class WaitForSignal : public QObject
+class WaitForSignal : public TQObject
 {
 public:
    ~WaitForSignal() { kapp->eventLoop()->exitLoop(); }
