@@ -467,7 +467,7 @@ static void writeImage24( TQImage &img, TQDataStream &s, PCXHEADER &header )
 
     for ( unsigned int x=0; x<header.width(); ++x )
     {
-      QRgb rgb = *p++;
+      TQRgb rgb = *p++;
       r_buf[ x ] = tqRed( rgb );
       g_buf[ x ] = tqGreen( rgb );
       b_buf[ x ] = tqBlue( rgb );
