@@ -123,7 +123,7 @@ ResourceLDAPTDEIO::~ResourceLDAPTDEIO()
 void ResourceLDAPTDEIO::enter_loop()
 {
   TQWidget dummy(0,0,(WFlags)(WType_Dialog | WShowModal));
-  dummy.setFocusPolicy( TQ_NoFocus );
+  dummy.setFocusPolicy( TQWidget::NoFocus );
   tqt_enter_modal(&dummy);
   tqApp->enter_loop();
   tqt_leave_modal(&dummy);
