@@ -331,8 +331,8 @@ void VCardFormatImpl::saveAddressee( const Addressee &addressee, VCARD::VCard *v
 
   addTextValue( v, EntityCategories, addressee.categories().join(",") );
 
-  addDateValue( v, EntityBirthday, TQT_TQDATE_OBJECT(addressee.birthday().date()) );
-  addDateTimeValue( v, EntityRevision, TQT_TQDATETIME_OBJECT(addressee.revision()) );
+  addDateValue( v, EntityBirthday, addressee.birthday().date() );
+  addDateTimeValue( v, EntityRevision, addressee.revision() );
   addGeoValue( v, addressee.geo() );
   addUTCValue( v, addressee.timeZone() );
 
