@@ -135,7 +135,7 @@ class TDECORE_EXPORT TDECompletion : public TQObject
     TQ_PROPERTY( CompOrder order READ order WRITE setOrder )
     TQ_PROPERTY( bool ignoreCase READ ignoreCase WRITE setIgnoreCase )
     TQ_PROPERTY( TQStringList items READ items WRITE setItems )
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     /**
