@@ -222,12 +222,7 @@ KExtendedSocket::~KExtendedSocket()
   delete d;
 }
 
-#ifdef USE_QT3
 void KExtendedSocket::reset()
-#endif // USE_QT3
-#ifdef USE_QT4
-bool KExtendedSocket::reset()
-#endif // USE_QT4
 {
   closeNow();
   release();
@@ -1262,7 +1257,7 @@ void KExtendedSocket::cancelAsyncConnect()
   d->status = lookupDone;
 }
 
-bool KExtendedSocket::open(TQ_OpenMode mode)
+bool KExtendedSocket::open(int mode)
 {
   if (mode != IO_Raw | IO_ReadWrite)
     return false;		// invalid open mode
@@ -1557,12 +1552,7 @@ int KExtendedSocket::unreadBlock(const char *, uint)
   return -1;
 }
 
-#ifdef USE_QT3
 int KExtendedSocket::bytesAvailable() const
-#endif // USE_QT3
-#ifdef USE_QT4
-qint64 KExtendedSocket::bytesAvailable() const
-#endif // USE_QT4
 {
   if (d->status < connected || d->flags & passiveSocket)
     return -2;
