@@ -22,10 +22,6 @@
 
 #include "tdelibs_export.h"
 
-#ifdef Q_MOC_RUN
-#define Q_OS_UNIX
-#endif // Q_MOC_RUN
-
 #ifdef Q_OS_UNIX
 
 #include <sys/time.h>
@@ -44,10 +40,10 @@ class KAddressInfo;		/* our abstraction of it */
 class TQSocketNotifier;
 
 /*
- * This is extending QIODevice's error codes
+ * This is extending TQIODevice's error codes
  *
  * According to tqiodevice.h, the last error is IO_UnspecifiedError
- * These errors will never occur in functions declared in QIODevice
+ * These errors will never occur in functions declared in TQIODevice
  * (except open, but you shouldn't call open)
  */
 #define IO_ListenError		(IO_UnspecifiedError+1)
@@ -92,9 +88,9 @@ class KExtendedSocketPrivate;
  * @author Thiago Macieira <thiago.macieira@kdemail.net>
  * @short an extended socket
  */
-class TDECORE_EXPORT KExtendedSocket: public TDEBufferedIO // public TQObject, public QIODevice
+class TDECORE_EXPORT KExtendedSocket: public TDEBufferedIO // public TQObject, public TQIODevice
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -211,12 +207,7 @@ public:
    * freeing any related resources still being kept.
    * @since 3.1
    */
-#ifdef USE_QT3
   void reset();
-#endif // USE_QT3
-#ifdef USE_QT4
-  bool reset();
-#endif // USE_QT4
 
   /*
    * --- status, flags and internal variables --- *
@@ -627,7 +618,7 @@ public:
    * @return true if successful, false when an error occurred or the most was
    *         not correct
    */
-  virtual bool open(TQ_OpenMode mode = (TQ_OpenMode)(IO_Raw | IO_ReadWrite));
+  virtual bool open(int mode = (int)(IO_Raw | IO_ReadWrite));
 
   /**
    * Closes the socket. If we have data still in the write buffer yet to be
@@ -685,12 +676,7 @@ public:
    * Returns length of this socket. This call is not supported on sockets.
    * @return the length of this socket, or 0 if unsupported
    */
-#ifdef USE_QT3
   virtual inline TQ_ULONG size() const
-#endif // USE_QT3
-#ifdef USE_QT4
-  virtual inline qint64 size() const
-#endif // USE_QT4
   { return 0; }
 
   /**
@@ -805,12 +791,7 @@ public:
    * @return The number of available bytes, or -1 on error or -2 if this call is invalid
    * in the current state.
    */
-#ifdef USE_QT3
   virtual int bytesAvailable() const;
-#endif // USE_QT3
-#ifdef USE_QT4
-  virtual qint64 bytesAvailable() const;
-#endif // USE_QT4
 
   /**
    * Waits @p msec milliseconds for more data to be available (use 0 to
