@@ -52,11 +52,17 @@
 // debug
 #include <sys/ioctl.h>
 
+#ifdef Q_OS_SOLARIS
+#include <sys/filio.h> /* FIONREAD is defined here */
+#endif /* solaris */
+
 #ifdef HAVE_INOTIFY
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/syscall.h>
+#ifdef Q_OS_LINUX
 #include <linux/types.h>
+#endif /* Linux */
 // Linux kernel headers are documented to not compile
 #define _S390_BITOPS_H
 #include <sys/inotify.h>
