@@ -93,12 +93,7 @@ void TDEBufferedSocket::close()
     }
 }
 
-#ifdef USE_QT3
 TQ_LONG TDEBufferedSocket::bytesAvailable() const
-#endif
-#ifdef USE_QT4
-qint64 TDEBufferedSocket::bytesAvailable() const
-#endif
 {
   if (!d->input)
     return KStreamSocket::bytesAvailable();
@@ -284,12 +279,7 @@ TDEIOBufferBase* TDEBufferedSocket::outputBuffer()
   return d->output;
 }
 
-#ifdef USE_QT3
 TQ_ULONG TDEBufferedSocket::bytesToWrite() const
-#endif
-#ifdef USE_QT4
-qint64 TDEBufferedSocket::bytesToWrite() const
-#endif
 {
   if (!d->output)
     return 0;
