@@ -48,16 +48,8 @@ public:
 };
 
 KClientSocketBase::KClientSocketBase(TQObject *parent, const char *name)  :
-#ifdef USE_QT4
-#else // USE_QT4
-    TQObject(parent, name),
-#endif // USE_QT4
-    d(new KClientSocketBasePrivate)
+    TQObject(parent, name), d(new KClientSocketBasePrivate)
 {
-#ifdef USE_QT4
-  setParent(parent);
-  setObjectName(name);
-#endif // USE_QT4
   d->state = Idle;
   d->enableRead = true;
   d->enableWrite = false;
@@ -286,12 +278,7 @@ void KClientSocketBase::close()
 }
 
 // This function is unlike all the others because it is const
-#ifdef USE_QT3
 TQ_LONG KClientSocketBase::bytesAvailable() const
-#endif
-#ifdef USE_QT4
-qint64 KClientSocketBase::bytesAvailable() const
-#endif
 {
   return socketDevice()->bytesAvailable();
 }
