@@ -32,10 +32,6 @@
 #include "kresolver.h"
 #include <tdelibs_export.h>
 
-#ifdef Q_MOC_RUN
-#define USE_QT4
-#endif // Q_MOC_RUN
-
 namespace KNetwork {
 
 class KClientSocketBasePrivate;
@@ -50,14 +46,9 @@ class KClientSocketBasePrivate;
  *
  * @author Thiago Macieira <thiago.macieira@kdemail.net>
  */
-class TDECORE_EXPORT KClientSocketBase :
-#ifdef USE_QT4
-#else // USE_QT4
-public TQObject,
-#endif // USE_QT4
-public KActiveSocketBase
+class TDECORE_EXPORT KClientSocketBase : public TQObject, public KActiveSocketBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -281,7 +272,7 @@ public:
    *
    * You should not call this function; instead, use @ref connect
    */
-  virtual inline bool open(TQ_OpenMode)
+  virtual inline bool open(int)
   { return connect(); }
 
   /**
@@ -302,12 +293,7 @@ public:
    * Returns the number of bytes available on this socket.
    * Reimplemented from TDESocketBase.
    */
-#ifdef USE_QT3
   virtual TQ_LONG bytesAvailable() const;
-#endif
-#ifdef USE_QT4
-  virtual qint64 bytesAvailable() const;
-#endif
 
   /**
    * Waits for more data. Reimplemented from TDESocketBase.
