@@ -550,7 +550,7 @@ void KResolver::emitFinished()
   emit finished(d->results);
 
   if (p && d->deleteWhenDone)
-    deleteLater();		// in QObject
+    deleteLater();		// in TQObject
 }
 
 TQString KResolver::errorString(int errorcode, int syserror)
