@@ -106,7 +106,7 @@ class TDEServerSocketPrivate;
  */
 class TDECORE_EXPORT TDEServerSocket: public TQObject, public KPassiveSocketBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   /**
