@@ -63,10 +63,10 @@
 #include <tdelibs_export.h>
 
 /*
- * This is extending QIODevice's error codes
+ * This is extending TQIODevice's error codes
  *
  * According to tqiodevice.h, the last error is IO_UnspecifiedError
- * These errors will never occur in functions declared in QIODevice
+ * These errors will never occur in functions declared in TQIODevice
  * (except open, but you shouldn't call open)
  */
 #define IO_ListenError		(IO_UnspecifiedError+1)
@@ -504,11 +504,7 @@ public:
    * This call is not supported on sockets. Reimplemented from TQIODevice.
    * This will always return 0.
    */
-#ifdef USE_QT4
-  virtual qint64 size() const
-#else // USE_QT4
   virtual Offset size() const
-#endif // USE_QT4
   { return 0; }
 
   /**
@@ -536,12 +532,7 @@ public:
    * Returns the number of bytes available for reading without
    * blocking.
    */
-#ifdef USE_QT3
   virtual TQ_LONG bytesAvailable() const = 0;
-#endif
-#ifdef USE_QT4
-  virtual qint64 bytesAvailable() const = 0;
-#endif
 
   /**
    * Waits up to @p msecs for more data to be available on this socket.
