@@ -1,4 +1,4 @@
-/*  -*- C++ -*-
+/*
  *  Copyright (C) 2003,2005 Thiago Macieira <thiago.macieira@kdemail.net>
  *
  *
@@ -171,7 +171,7 @@ bool TDESocketDevice::setSocketOptions(int opts)
   return true;			// all went well
 }
 
-bool TDESocketDevice::open(TQ_OpenMode)
+bool TDESocketDevice::open(int)
 {
   resetError();
   return false;
@@ -364,12 +364,7 @@ bool TDESocketDevice::disconnect()
   return true;			// all is well
 }
 
-#ifdef USE_QT3
 TQ_LONG TDESocketDevice::bytesAvailable() const
-#endif
-#ifdef USE_QT4
-qint64 TDESocketDevice::bytesAvailable() const
-#endif
 {
   if (m_sockfd == -1)
     return -1;			// there's nothing to read in a closed socket
