@@ -435,7 +435,7 @@ TQVariant TDEConfigBase::readPropertyEntry( const char *pKey,
       case TQVariant::DateTime:
           return TQVariant( readDateTimeEntry( pKey, &tmp.asDateTime() ) );
       case TQVariant::Date:
-          return TQVariant(TQT_TQDATE_OBJECT(readDateTimeEntry( pKey, &tmp.asDateTime() ).date()));
+          return TQVariant(readDateTimeEntry( pKey, &tmp.asDateTime() ).date());
 
       case TQVariant::Pixmap:
       case TQVariant::Image:
@@ -451,34 +451,10 @@ TQVariant TDEConfigBase::readPropertyEntry( const char *pKey,
       case TQVariant::Cursor:
       case TQVariant::SizePolicy:
       case TQVariant::Time:
-#ifdef USE_QT3
       case TQVariant::ByteArray:
-#endif // USE_QT3
       case TQVariant::BitArray:
       case TQVariant::KeySequence:
       case TQVariant::Pen:
-#ifdef USE_QT4
-      case TQVariant::Char:
-      case TQVariant::Url:
-      case TQVariant::Locale:
-      case TQVariant::RectF:
-      case TQVariant::SizeF:
-      case TQVariant::Line:
-      case TQVariant::LineF:
-      case TQVariant::PointF:
-      case TQVariant::RegExp:
-      case TQVariant::Hash:
-      case TQVariant::TextLength:
-      case QVariant::TextFormat:
-      case TQVariant::Matrix:
-      case TQVariant::Transform:
-      case TQVariant::Matrix4x4:
-      case TQVariant::Vector2D:
-      case TQVariant::Vector3D:
-      case TQVariant::Vector4D:
-      case TQVariant::Quaternion:
-      case TQVariant::UserType:
-#endif // USE_QT4
       {
           break;
       }
@@ -983,7 +959,7 @@ TQColor TDEConfigBase::readColorEntry( const char *pKey,
   TQString aValue = readEntry( pKey );
   if( !aValue.isEmpty() )
     {
-      if ( aValue.at(0) == (QChar)'#' )
+      if ( aValue.at(0) == (TQChar)'#' )
         {
           aRetColor.setNamedColor(aValue);
         }
@@ -1378,34 +1354,10 @@ void TDEConfigBase::writeEntry ( const char *pKey, const TQVariant &prop,
     case TQVariant::Cursor:
     case TQVariant::SizePolicy:
     case TQVariant::Time:
-#ifdef USE_QT3
     case TQVariant::ByteArray:
-#endif // USE_QT3
     case TQVariant::BitArray:
     case TQVariant::KeySequence:
     case TQVariant::Pen:
-#ifdef USE_QT4
-    case TQVariant::Char:
-    case TQVariant::Url:
-    case TQVariant::Locale:
-    case TQVariant::RectF:
-    case TQVariant::SizeF:
-    case TQVariant::Line:
-    case TQVariant::LineF:
-    case TQVariant::PointF:
-    case TQVariant::RegExp:
-    case TQVariant::Hash:
-    case TQVariant::TextLength:
-    case QVariant::TextFormat:
-    case TQVariant::Matrix:
-    case TQVariant::Transform:
-    case TQVariant::Matrix4x4:
-    case TQVariant::Vector2D:
-    case TQVariant::Vector3D:
-    case TQVariant::Vector4D:
-    case TQVariant::Quaternion:
-    case TQVariant::UserType:
-#endif // USE_QT4
       {
         break;
       }
@@ -1449,7 +1401,7 @@ void TDEConfigBase::writeEntry ( const char *pKey, const TQStrList &list,
         }
       str_list += sep;
     }
-  if( str_list.at(str_list.length() - 1) == (QChar)sep )
+  if( str_list.at(str_list.length() - 1) == (TQChar)sep )
     str_list.truncate( str_list.length() -1 );
   writeEntry( pKey, str_list, bPersistent, bGlobal, bNLS );
 }
@@ -1493,7 +1445,7 @@ void TDEConfigBase::writeEntry ( const char *pKey, const TQStringList &list,
         }
       str_list += sep;
     }
-  if( str_list.at(str_list.length() - 1) == (QChar)sep )
+  if( str_list.at(str_list.length() - 1) == (TQChar)sep )
     str_list.truncate( str_list.length() -1 );
   writeEntry( pKey, str_list, bPersistent, bGlobal, bNLS, bExpand );
 }
@@ -1757,8 +1709,8 @@ void TDEConfigBase::writeEntry( const char *pKey, const TQDateTime& rDateTime,
   TQStrList list;
   TQCString tempstr;
 
-  TQTime time = TQT_TQTIME_OBJECT(rDateTime.time());
-  TQDate date = TQT_TQDATE_OBJECT(rDateTime.date());
+  TQTime time = rDateTime.time();
+  TQDate date = rDateTime.date();
 
   list.insert( 0, tempstr.setNum( date.year() ) );
   list.insert( 1, tempstr.setNum( date.month() ) );
