@@ -81,7 +81,7 @@ typedef TQDict<TDECPUDevice> TDECPUDeviceCache;
 
 class TDECORE_EXPORT TDEHardwareDevices : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 	public:	
 		/**
