@@ -263,7 +263,7 @@ TQString TDEStyle::defaultStyle()
 
 void TDEStyle::polish( const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, void *ptr )
 {
-	if (ceData.widgetObjectTypes.contains(TQWIDGET_OBJECT_NAME_STRING)) {
+	if (ceData.widgetObjectTypes.contains("TQWidget")) {
 		TQWidget* widget = reinterpret_cast<TQWidget*>(ptr);
 		if ( d->useFilledFrameWorkaround )
 		{
@@ -287,7 +287,7 @@ void TDEStyle::polish( const TQStyleControlElementData &ceData, ControlElementFl
 
 void TDEStyle::unPolish( const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, void *ptr )
 {
-	if (ceData.widgetObjectTypes.contains(TQWIDGET_OBJECT_NAME_STRING)) {
+	if (ceData.widgetObjectTypes.contains("TQWidget")) {
 		TQWidget* widget = reinterpret_cast<TQWidget*>(ptr);
 		if ( d->useFilledFrameWorkaround )
 		{
@@ -310,7 +310,7 @@ void TDEStyle::polishPopupMenu( const TQStyleControlElementData &ceData, Control
         widgetActionRequest(ceData, elementFlags, ptr, WAR_SetCheckable);
     }
 
-	if (ceData.widgetObjectTypes.contains(TQWIDGET_OBJECT_NAME_STRING)) {
+	if (ceData.widgetObjectTypes.contains("TQWidget")) {
 		TQWidget* widget = reinterpret_cast<TQWidget*>(ptr);
 		TQPopupMenu *p = dynamic_cast<TQPopupMenu*>(widget);
 		if (p) {
@@ -569,29 +569,7 @@ int TDEStyle::kPixelMetric( TDEStylePixelMetric kpm, const TQStyleControlElement
 
 // -----------------------------------------------------------------------------
 
-// #ifdef USE_QT4 // tdebindings / smoke needs this function declaration available at all times.  Furthermore I don't think it would hurt to have the declaration available at all times...so leave these commented out for now
-
-//void TDEStyle::drawPrimitive( TQ_ControlElement pe,
-//							TQPainter* p,
-// 							const TQStyleControlElementData &ceData,
-// 							ControlElementFlags elementFlags,
-//							const TQRect &r,
-//							const TQColorGroup &cg,
-//							SFlags flags,
-//							const TQStyleOption& opt ) const
-//{
-//	// FIXME:
-//	// What should "widget" be in actuality?  How should I get it?  From where?
-//	// Almost certainly it should not be null!
-//	TQWidget *widget = 0;
-//	drawControl(pe, p, ceData, elementFlags, r, cg, flags, opt, widget);
-//}
-
-// #endif // USE_QT4
-
-// -----------------------------------------------------------------------------
-
-void TDEStyle::drawPrimitive( TQ_PrimitiveElement pe,
+void TDEStyle::drawPrimitive( PrimitiveElement pe,
 							TQPainter* p,
 							const TQStyleControlElementData &ceData,
 							ControlElementFlags elementFlags,
@@ -615,13 +593,13 @@ void TDEStyle::drawPrimitive( TQ_PrimitiveElement pe,
 
 		// Check if we are a normal toolbar or a hidden dockwidget.
 		if ( parent &&
-			(parent->inherits(TQTOOLBAR_OBJECT_NAME_STRING) ||		// Normal toolbar
-			(parent->inherits(TQMAINWINDOW_OBJECT_NAME_STRING)) ))	// Collapsed dock
+			(parent->inherits("TQToolBar") ||		// Normal toolbar
+			(parent->inherits("TQMainWindow")) ))	// Collapsed dock
 
 			// Draw a toolbar handle
 			drawTDEStylePrimitive( KPE_ToolBarHandle, p, ceData, elementFlags, r, cg, flags, opt, widget );
 
-		else if (ceData.widgetObjectTypes.contains(TQDOCKWINDOWHANDLE_OBJECT_NAME_STRING))
+		else if (ceData.widgetObjectTypes.contains("TQDockWindowHandle"))
 
 			// Draw a dock window handle
 			drawTDEStylePrimitive( KPE_DockWindowHandle, p, ceData, elementFlags, r, cg, flags, opt, widget );
@@ -1025,9 +1003,9 @@ int TDEStyle::pixelMetric(PixelMetric m, const TQStyleControlElementData &ceData
 			// Check that we are not a normal toolbar or a hidden dockwidget,
 			// in which case we need to adjust the height for font size
 			if (widget
-				&& !(ceData.parentWidgetData.widgetObjectTypes.contains(TQTOOLBAR_OBJECT_NAME_STRING))
-				&& !(ceData.parentWidgetData.widgetObjectTypes.contains(TQMAINWINDOW_OBJECT_NAME_STRING))
-				&& (ceData.widgetObjectTypes.contains(TQDOCKWINDOWHANDLE_OBJECT_NAME_STRING)) )
+				&& !(ceData.parentWidgetData.widgetObjectTypes.contains("TQToolBar"))
+				&& !(ceData.parentWidgetData.widgetObjectTypes.contains("TQMainWindow"))
+				&& (ceData.widgetObjectTypes.contains("TQDockWindowHandle")) )
 					return widget->fontMetrics().lineSpacing();
 			else
 				return TQCommonStyle::pixelMetric(m, ceData, elementFlags, widget);
@@ -1086,7 +1064,7 @@ int TDEStyle::pixelMetric(PixelMetric m, const TQStyleControlElementData &ceData
 		// SPLITTER
 		// ------------------------------------------------------------------------
 		case PM_SplitterWidth:
-			if (ceData.widgetObjectTypes.contains(TQDOCKWINDOWRESIZEHANDLE_OBJECT_NAME_STRING))
+			if (ceData.widgetObjectTypes.contains("TQDockWindowResizeHandle"))
 				return 8;	// ### why do we need 2pix extra?
 			else
 				return 6;
@@ -1875,7 +1853,7 @@ TQPixmap TDEStyle::stylePixmap( StylePixmap stylepixmap,
 }
 
 
-int TDEStyle::styleHint( TQ_StyleHint sh, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags,
+int TDEStyle::styleHint( StyleHint sh, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags,
 					   const TQStyleOption &opt, TQStyleHintReturn* shr, const TQWidget* w) const
 {
 	switch (sh)
@@ -1936,7 +1914,7 @@ int TDEStyle::styleHint( TQ_StyleHint sh, const TQStyleControlElementData &ceDat
 
 bool TDEStyle::objectEventHandler( const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, void* source, TQEvent *event )
 {
-	if (ceData.widgetObjectTypes.contains(TQOBJECT_OBJECT_NAME_STRING)) {
+	if (ceData.widgetObjectTypes.contains("TQObject")) {
 		TQObject* object = reinterpret_cast<TQObject*>(source);
 		if ( d->useFilledFrameWorkaround )
 		{
@@ -2410,8 +2388,4 @@ void kde_tdestyle_set_scrollbar_type_windows( void* style )
 {
     ((TDEStyle*)style)->setScrollBarType( TDEStyle::WindowsStyleScrollBar );
 }
-
-// vim: set noet ts=4 sw=4:
-// kate: indent-width 4; replace-tabs off; tab-width 4; space-indent off;
-
 #include "tdestyle.moc"
