@@ -56,7 +56,7 @@ struct TDEStylePrivate;
  */
 class TDEFX_EXPORT TDEStyle: public TQCommonStyle
 {
-	Q_OBJECT
+	TQ_OBJECT
 	
 
 	public:
@@ -287,7 +287,7 @@ class TDEFX_EXPORT TDEStyle: public TQCommonStyle
 		void unPolish( const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, void * );
 		void polishPopupMenu( const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, void *ptr );
 
-		void drawPrimitive( TQ_PrimitiveElement pe,
+		void drawPrimitive( PrimitiveElement pe,
 					TQPainter* p,
 					const TQStyleControlElementData &ceData,
 					ControlElementFlags elementFlags,
@@ -296,19 +296,6 @@ class TDEFX_EXPORT TDEStyle: public TQCommonStyle
 					SFlags flags = Style_Default,
 					const TQStyleOption& = TQStyleOption::SO_Default ) const;
 
-// #ifdef USE_QT4 // tdebindings / smoke needs this function declaration available at all times.  Furthermore I don't think it would hurt to have the declaration available at all times...so leave these commented out for now
-
-//		void drawPrimitive( TQ_ControlElement pe,
-//					TQPainter* p,
-// 					const TQStyleControlElementData &ceData,
-// 					ControlElementFlags elementFlags,
-//					const TQRect &r,
-//					const TQColorGroup &cg,
-//					SFlags flags = Style_Default,
-//					const TQStyleOption& = TQStyleOption::SO_Default ) const;
-
-// #endif // USE_QT4
-
 		void drawControl( TQ_ControlElement element,
 					TQPainter* p,
 					const TQStyleControlElementData &ceData,
@@ -357,7 +344,7 @@ class TDEFX_EXPORT TDEStyle: public TQCommonStyle
 					const TQStyleOption& = TQStyleOption::SO_Default,
 					const TQWidget* widget = 0 ) const;
 
-		int styleHint( TQ_StyleHint sh, const TQStyleControlElementData &ceData,
+		int styleHint( StyleHint sh, const TQStyleControlElementData &ceData,
 					ControlElementFlags elementFlags,
 					const TQStyleOption &opt = TQStyleOption::SO_Default,
 					TQStyleHintReturn* shr = 0,
