@@ -246,7 +246,7 @@ namespace KJS {
   };
 
   class KDE_EXPORT WindowQObject : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   public:
     WindowQObject(Window *w);
     ~WindowQObject();
