@@ -122,7 +122,7 @@ namespace KJS {
 
 
   class XMLHttpRequestQObject : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
 
   public:
     XMLHttpRequestQObject(XMLHttpRequest *_jsObject);
