@@ -51,7 +51,7 @@ inline
 #endif
 #endif
 static unsigned int
-hash (register const char *str, register unsigned int len)
+hash (const char *str, unsigned int len)
 {
   static const unsigned short asso_values[] =
     {
@@ -82,7 +82,7 @@ hash (register const char *str, register unsigned int len)
       731, 731, 731, 731, 731, 731, 731, 731, 731, 731,
       731, 731, 731, 731, 731, 731
     };
-  register int hval = len;
+  int hval = len;
 
   switch (hval)
     {
@@ -334,7 +334,7 @@ hash (register const char *str, register unsigned int len)
 __inline
 #endif
 const struct PubIDInfo *
-findDoctypeEntry (register const char *str, register unsigned int len)
+findDoctypeEntry (const char *str, unsigned int len)
 {
   enum
     {
@@ -1160,11 +1160,11 @@ findDoctypeEntry (register const char *str, register unsigned int len)
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
     {
-      register int key = hash (str, len);
+      int key = hash (str, len);
 
       if (key <= MAX_HASH_VALUE && key >= 0)
         {
-          register const char *s = wordlist[key].name;
+          const char *s = wordlist[key].name;
 
           if (*str == *s && !strcmp (str + 1, s + 1))
             return &wordlist[key];
