@@ -957,14 +957,14 @@ bool HTMLGenericFormElementImpl::isFocusable() const
 	return false;
 
     TQWidget* widget = static_cast<RenderWidget*>(m_render)->widget();
-    return widget && widget->focusPolicy() >= TQ_TabFocus;
+    return widget && widget->focusPolicy() >= TQWidget::TabFocus;
 }
 
 class FocusHandleWidget : public TQWidget
 {
 public:
     void focusNextPrev(bool n) {
-        if (!focusNextPrevChild(n) && inherits(TQTEXTEDIT_OBJECT_NAME_STRING))
+        if (!focusNextPrevChild(n) && inherits("TQTextEdit"))
             TQWidget::focusNextPrevChild(n);
     }
 };
@@ -1020,17 +1020,11 @@ void HTMLGenericFormElementImpl::defaultEventHandler(EventImpl *evt)
 	        TQKeyEvent* const k = static_cast<KeyEventBaseImpl *>(evt)->qKeyEvent();
 	        if ( k && (k->key() == Qt::Key_Tab || k->key() == TQt::Key_BackTab) ) {
 		    TQWidget* const widget = static_cast<RenderWidget*>(m_render)->widget();
-#ifdef USE_QT4
-		    if (widget)
-                        static_cast<FocusHandleWidget *>(widget)
-			    ->focusNextPrev(k->key() == Qt::Key_Tab);
-#else // USE_QT4
 		    TQFocusEvent::setReason( k->key() == Qt::Key_Tab ? TQFocusEvent::Tab : TQFocusEvent::Backtab );
 		    if (widget)
                         static_cast<FocusHandleWidget *>(widget)
 			    ->focusNextPrev(k->key() == Qt::Key_Tab);
 		    TQFocusEvent::resetReason();
-#endif // USE_QT4
                     evt->setDefaultHandled();
 	        }
             }
