@@ -79,7 +79,7 @@ public:
     void setServer (KJavaAppletServer * s);
     TQGuardedPtr <KJavaAppletServer> server;
 private:
-    typedef TQMap <QPair <TQObject*, TQString>, QPair <KJavaAppletContext*, int> >
+    typedef TQMap <TQPair <TQObject*, TQString>, TQPair <KJavaAppletContext*, int> >
             ContextMap;
     ContextMap m_contextmap;
 };
