@@ -75,7 +75,7 @@ class KJavaAppletWidgetPrivate;
 
 class KJavaAppletWidget : public QXEmbed
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     KJavaAppletWidget( TQWidget* parent=0, const char* name=0 );
 
