@@ -99,7 +99,7 @@ void RenderFormElement::layout()
     setNeedsLayout(false);
 }
 
-TQ_Alignment RenderFormElement::textAlignment() const
+Qt::AlignmentFlags RenderFormElement::textAlignment() const
 {
     switch (style()->textAlign()) {
         case LEFT:
@@ -907,7 +907,7 @@ bool ComboBoxWidget::event(TQEvent *e)
 
 bool ComboBoxWidget::eventFilter(TQObject *dest, TQEvent *e)
 {
-    if (TQT_BASE_OBJECT(dest)==TQT_BASE_OBJECT(listBox()) &&  e->type()==TQEvent::KeyPress)
+    if (dest==listBox() &&  e->type()==TQEvent::KeyPress)
     {
 	TQKeyEvent *ke = TQT_TQKEYEVENT(e);
 	bool forward = false;
