@@ -114,7 +114,7 @@ void TDEHTMLPartBrowserExtension::editableWidgetFocused( TQWidget *widget )
         connect( TQApplication::clipboard(), TQT_SIGNAL( dataChanged() ),
                  this, TQT_SLOT( updateEditActions() ) );
 
-        if ( m_editableFormWidget->inherits( TQLINEEDIT_OBJECT_NAME_STRING ) || m_editableFormWidget->inherits( TQTEXTEDIT_OBJECT_NAME_STRING ) )
+        if ( m_editableFormWidget->inherits( "TQLineEdit" ) || m_editableFormWidget->inherits( "TQTextEdit" ) )
             connect( m_editableFormWidget, TQT_SIGNAL( selectionChanged() ),
                      this, TQT_SLOT( updateEditActions() ) );
 
@@ -139,7 +139,7 @@ void TDEHTMLPartBrowserExtension::editableWidgetBlurred( TQWidget * /*widget*/ )
 
         if ( oldWidget )
         {
-            if ( oldWidget->inherits( TQLINEEDIT_OBJECT_NAME_STRING ) || oldWidget->inherits( TQTEXTEDIT_OBJECT_NAME_STRING ) )
+            if ( oldWidget->inherits( "TQLineEdit" ) || oldWidget->inherits( "TQTextEdit" ) )
                 disconnect( oldWidget, TQT_SIGNAL( selectionChanged() ),
                             this, TQT_SLOT( updateEditActions() ) );
         }
@@ -200,9 +200,9 @@ void TDEHTMLPartBrowserExtension::cut()
     if ( !m_editableFormWidget )
         return;
 
-    if ( m_editableFormWidget->inherits( TQLINEEDIT_OBJECT_NAME_STRING ) )
+    if ( m_editableFormWidget->inherits( "TQLineEdit" ) )
         static_cast<TQLineEdit *>( &(*m_editableFormWidget) )->cut();
-    else if ( m_editableFormWidget->inherits( TQTEXTEDIT_OBJECT_NAME_STRING ) )
+    else if ( m_editableFormWidget->inherits( "TQTextEdit" ) )
         static_cast<TQTextEdit *>( &(*m_editableFormWidget) )->cut();
 }
 
@@ -253,9 +253,9 @@ void TDEHTMLPartBrowserExtension::copy()
     }
     else
     {
-        if ( m_editableFormWidget->inherits( TQLINEEDIT_OBJECT_NAME_STRING ) )
+        if ( m_editableFormWidget->inherits( "TQLineEdit" ) )
             static_cast<TQLineEdit *>( &(*m_editableFormWidget) )->copy();
-        else if ( m_editableFormWidget->inherits( TQTEXTEDIT_OBJECT_NAME_STRING ) )
+        else if ( m_editableFormWidget->inherits( "TQTextEdit" ) )
             static_cast<TQTextEdit *>( &(*m_editableFormWidget) )->copy();
     }
 }
@@ -263,7 +263,7 @@ void TDEHTMLPartBrowserExtension::copy()
 void TDEHTMLPartBrowserExtension::searchProvider()
 {
     // action name is of form "previewProvider[<searchproviderprefix>:]"
-    const TQString searchProviderPrefix = TQString( TQT_TQOBJECT_CONST(sender())->name() ).mid( 14 );
+    const TQString searchProviderPrefix = TQString( sender()->name() ).mid( 14 );
 
     KURIFilterData data;
     TQStringList list;
@@ -303,9 +303,9 @@ void TDEHTMLPartBrowserExtension::paste()
     if ( !m_editableFormWidget )
         return;
 
-    if ( m_editableFormWidget->inherits( TQLINEEDIT_OBJECT_NAME_STRING ) )
+    if ( m_editableFormWidget->inherits( "TQLineEdit" ) )
         static_cast<TQLineEdit *>( &(*m_editableFormWidget) )->paste();
-    else if ( m_editableFormWidget->inherits( TQTEXTEDIT_OBJECT_NAME_STRING ) )
+    else if ( m_editableFormWidget->inherits( "TQTextEdit" ) )
         static_cast<TQTextEdit *>( &(*m_editableFormWidget) )->paste();
 }
 
