@@ -164,7 +164,7 @@ IdleSlave::age(time_t now)
 
 TDELauncher::TDELauncher(int _tdeinitSocket, bool new_startup)
 //  : TDEApplication( false, false ), // No Styles, No GUI
-  : TDEApplication( false, true ),	// TQClipboard tries to construct a QWidget so a GUI is technically needed, even though it is not used
+  : TDEApplication( false, true ),	// TQClipboard tries to construct a TQWidget so a GUI is technically needed, even though it is not used
     DCOPObject("tdelauncher"),
     tdeinitSocket(_tdeinitSocket), mAutoStart( new_startup ),
     dontBlockReading(false), newStartup( new_startup )
