@@ -345,7 +345,15 @@ TDEConfig *cfg;
    libnamesc << "cygcrypto.dll"
 		 << "libcrypto.dll"
 		 << "";
-#else
+#else /* !OpenBSD && !CygWin */
+
+#ifdef Q_OS_SOLARIS
+
+   libpaths << "/" SYSTEM_LIBDIR KDELIBSUFF "/"
+	    << "/usr/" SYSTEM_LIBDIR KDELIBSUFF "/"
+	    << "";
+#else /* default */
+
    libpaths
 	    #ifdef _AIX
 	    << "/opt/freeware/lib/"
@@ -358,6 +366,7 @@ TDEConfig *cfg;
 	    << "/opt/openssl/" SYSTEM_LIBDIR "/"
 	    << "/" SYSTEM_LIBDIR "/"
 	    << "";
+#endif /* default */
 
 // FIXME: #define here for the various OS types to optimize
    libnamess
@@ -401,7 +410,7 @@ TDEConfig *cfg;
 	       << "libcrypto.so.0"
 	     #endif
 	     ;
-#endif
+#endif /* __OpenBSD__ */
 
    for (TQStringList::Iterator it = libpaths.begin();
                               it != libpaths.end();
