@@ -410,7 +410,7 @@ void KURLBar::setListBox( KURLBarListBox *view )
 
     m_listBox->setSelectionMode( TDEListBox::Single );
     paletteChange( palette() );
-    m_listBox->setFocusPolicy( TQ_TabFocus );
+    m_listBox->setFocusPolicy( TQWidget::TabFocus );
 
     connect( m_listBox, TQT_SIGNAL( mouseButtonClicked( int, TQListBoxItem *, const TQPoint & ) ),
              TQT_SLOT( slotSelected( int, TQListBoxItem * )));
