@@ -229,7 +229,7 @@ class KURLBarListBox;
  */
 class TDEIO_EXPORT KURLBar : public TQFrame
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     /**
@@ -492,7 +492,7 @@ class KURLBarToolTip;
  */
 class TDEIO_EXPORT KURLBarListBox : public TDEListBox
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     /**
@@ -566,7 +566,7 @@ class KURLRequester;
  */
 class TDEIO_EXPORT KURLBarItemDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     /**
