@@ -1,4 +1,3 @@
-// -*- c++ -*-
 /* This file is part of the KDE libraries
     Copyright (C) 1997, 1998 Richard Moore <rich@kde.org>
                   1998 Stephan Kulow <coolo@kde.org>
@@ -334,20 +333,10 @@ void KFileDialog::slotOk()
 {
     kdDebug(tdefile_area) << "slotOK\n";
 
-    // If the user typed in the path field without confirming it with ENTER,
-    // "ops" will most likely point do a different folder. Make sure the folder exists,
-    // then update "ops" accordingly and only if necessary
-    TQDir savedir = TQDir(d->pathCombo->lineEdit()->text());
-    if (!savedir.exists())
-    {
-			KMessageBox::information(this, i18n("The selected folder does not exists. Please select an existing one."));
-			return;
-    }
-    if (ops->url().path(1) != KURL(savedir.absPath()).path(1)) 
-    {
-    	setURL(savedir.absPath());
-    }
-    
+		if (locationEdit->lineEdit()->edited())
+		{
+			enterURL(d->pathCombo->lineEdit()->text());
+		}
     // a list of all selected files/directories (if any)
     // can only be used if the user didn't type any filenames/urls himself
     const KFileItemList *items = ops->selectedItems();
@@ -999,9 +988,9 @@ void KFileDialog::init(const TQString& startDir, const TQString& filter, TQWidge
              this,  TQT_SLOT( enterURL( const KURL& ) ));
     connect( d->pathCombo, TQT_SIGNAL( returnPressed( const TQString& )),
              this,  TQT_SLOT( enterURL( const TQString& ) ));
-    connect( d->pathCombo, TQT_SIGNAL( activated( const TQString& )),
-             this,  TQT_SLOT( enterURL( const TQString& ) ));
-
+		connect( d->pathCombo, TQT_SIGNAL( activated( const TQString& )),
+              this,  TQT_SLOT( enterURL( const TQString& ) ));
+              
     TQString whatsThisText;
 
     // the Location label/edit
@@ -1183,12 +1172,6 @@ void KFileDialog::urlEntered(const KURL& url)
         d->pathCombo->setURL( url );
     }
 
-    if (url.protocol()=="beagle" && url.path()=="/") {
-       d->pathCombo->setEditText("beagle:/<"+i18n("search term")+">");
-       d->pathCombo->lineEdit()->setSelection(8,255);
-       d->pathCombo->setFocus();
-    }
-
     locationEdit->blockSignals( true );
     locationEdit->setCurrentItem( 0 );
     if ( d->keepLocation )
