@@ -75,7 +75,7 @@ struct KFileDialogPrivate;
  */
 class TDEIO_EXPORT KFileDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
 
@@ -268,7 +268,7 @@ public:
      * tdefile->setFilter("*.cpp");
      * tdefile->setFilter("*.cpp|Sources (*.cpp)");
      * tdefile->setFilter("*.cpp|" + i18n("Sources (*.cpp)"));
-     * tdefile->setFilter("*.cpp *.cc *.C|C++ Source Files\n*.h *.H|Header files");
+     * tdefile->setFilter("*.cpp|C++ Source Files\n*.h|Header files");
      * \endcode
      *
      * Note: The text to display is not parsed in any way. So, if you
@@ -359,7 +359,7 @@ public:
      * This widget has to inherit TQWidget and it has to implement
      * a slot showPreview(const KURL &); which is called
      * every time the file changes. You may want to look at
-     * koffice/lib/kofficecore/koFilterManager.cc for some hints :)
+     * koffice/lib/kofficecore/koFilterManager.cpp for some hints :)
      *
      * Ownership is transferred to KFileDialog. You need to create the
      * preview-widget with "new", i.e. on the heap.
@@ -811,7 +811,7 @@ signals:
      * or chose one of the predefined set via setFilter().
      *
      * @param filter contains the new filter (only the extension part,
-     * not the explanation), i.e. "*.cpp" or "*.cpp *.cc".
+     * not the explanation), i.e. "*.cpp".
      *
      * @see setFilter()
      * @see currentFilter()
