@@ -1307,6 +1307,8 @@ TDEIO_EXPORT TQByteArray TDEIO::rawErrorDetail(int errorCode, const TQString &er
 #endif
 #ifdef HAVE_SYS_UCRED_H
 #include <sys/ucred.h>
+#elifdef HAVE_UCRED_H
+#include <ucred.h>
 #endif
 #ifdef HAVE_SYS_MOUNT_H
 #include <sys/mount.h>
