@@ -935,7 +935,7 @@ void KDirListerCache::slotFileDirty( const KURL& _url )
 // delayed updating of files, FAM is flooding us with events
 void KDirListerCache::slotFileDirtyDelayed()
 {
-  TQString file = TQString::fromUtf8( TQT_TQOBJECT_CONST(sender())->name() );
+  TQString file = TQString::fromUtf8( sender()->name() );
 
   kdDebug(7004) << k_funcinfo << file << endl;
 
@@ -2398,7 +2398,6 @@ void KDirLister::addNewItems( const KFileItemList& items )
   // TODO: make this faster - test if we have a filter at all first
   // DF: was this profiled? The matchesFoo() functions should be fast, w/o filters...
   // Of course if there is no filter and we can do a range-insertion instead of a loop, that might be good.
-  // But that's for Qt4, not possible with TQPtrList.
   for ( KFileItemListIterator kit( items ); kit.current(); ++kit ) {
     addNewItem( *kit );
   }
