@@ -388,7 +388,7 @@ void KMimeType::init( KDesktopFile * config )
   // Read the X-TDE-AutoEmbed setting and store it in the properties map
   TQString XKDEAutoEmbed = TQString::fromLatin1("X-TDE-AutoEmbed");
   if ( config->hasKey( XKDEAutoEmbed ) )
-    m_mapProps.insert( XKDEAutoEmbed, TQVariant( config->readBoolEntry( XKDEAutoEmbed ), 0 ) );
+    m_mapProps.insert( XKDEAutoEmbed, TQVariant( config->readBoolEntry( XKDEAutoEmbed ) ) );
 
   TQString XKDEText = TQString::fromLatin1("X-TDE-text");
   if ( config->hasKey( XKDEText ) )
