@@ -306,7 +306,7 @@ public:
     /**
      * Overloaded assigenment operator.
      *
-     * This function allows you to easily assign a QString
+     * This function allows you to easily assign a TQString
      * to a KURIFilterData object.
      *
      * @return an instance of a KURIFilterData object.
@@ -362,7 +362,7 @@ private:
  */
 class TDEIO_EXPORT KURIFilterPlugin : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
     
 
 public:
