@@ -487,7 +487,7 @@ bool NetAccess::synchronousRunInternal( Job* job, TQWidget* window, TQByteArray*
 
   TQMetaObject *meta = job->metaObject();
 
-  static const char dataSignal[] = "data(TDEIO::Job*,const " TQBYTEARRAY_OBJECT_NAME_STRING "&)";
+  static const char dataSignal[] = "data(TDEIO::Job*,const " "TQByteArray" "&)";
   if ( meta->findSignal( dataSignal ) != -1 ) {
       connect( job, TQT_SIGNAL(data(TDEIO::Job*,const TQByteArray&)),
                this, TQT_SLOT(slotData(TDEIO::Job*,const TQByteArray&)) );
@@ -516,7 +516,7 @@ void tqt_leave_modal( TQWidget *widget );
 void NetAccess::enter_loop()
 {
   TQWidget dummy(0,0,(WFlags)(WType_Dialog | WShowModal));
-  dummy.setFocusPolicy( TQ_NoFocus );
+  dummy.setFocusPolicy( TQWidget::NoFocus );
   tqt_enter_modal(&dummy);
   tqApp->enter_loop();
   tqt_leave_modal(&dummy);
