@@ -42,7 +42,7 @@ namespace TDEIO {
     */
     class TDEIO_EXPORT Slave : public TDEIO::SlaveInterface
     {
-	Q_OBJECT
+	TQ_OBJECT
 	
 
     protected:
