@@ -172,7 +172,7 @@ void KFileItem::init( bool _determineMimeTypeOnDemand )
           if ( KDE_stat( path.data(), &buf ) == 0 ) {
               mode = buf.st_mode;
           }
-          else { // link pointing to nowhere (see tdeio/file/file.cc)
+          else { // link pointing to nowhere (see tdeio/file/file.cpp)
               mode = (S_IFMT-1) | S_IRWXU | S_IRWXG | S_IRWXO;
           }
         }
@@ -700,7 +700,7 @@ TQPixmap KFileItem::pixmap( int _size, int _state ) const
   if (p.isNull())
       kdWarning() << "Pixmap not found for mimetype " << m_pMimeType->name() << endl;
 
-  if ( mime->name() == "application/x-executable" ) {
+  if ( mime->name() == "application/x-executable" || mime->name() == "application/x-pie-executable" ) {
 	// At first glance it might seem to be a good idea to
 	// look for .desktop files for this executable before resorting to the embedded icon
 	// in the same fashion as the minicli, but on close examination this is NOT A GOOD IDEA.
