@@ -149,15 +149,15 @@ KMdiChildFrm::KMdiChildFrm( KMdiChildArea *parent )
 
 	redecorateButtons();
 
-	m_pWinIcon->setFocusPolicy( TQ_NoFocus );
-	m_pUnixIcon->setFocusPolicy( TQ_NoFocus );
-	m_pClose->setFocusPolicy( TQ_NoFocus );
-	m_pMinimize->setFocusPolicy( TQ_NoFocus );
-	m_pMaximize->setFocusPolicy( TQ_NoFocus );
-	m_pUndock->setFocusPolicy( TQ_NoFocus );
+	m_pWinIcon->setFocusPolicy( TQWidget::NoFocus );
+	m_pUnixIcon->setFocusPolicy( TQWidget::NoFocus );
+	m_pClose->setFocusPolicy( TQWidget::NoFocus );
+	m_pMinimize->setFocusPolicy( TQWidget::NoFocus );
+	m_pMaximize->setFocusPolicy( TQWidget::NoFocus );
+	m_pUndock->setFocusPolicy( TQWidget::NoFocus );
 
 	setFrameStyle( TQFrame::WinPanel | TQFrame::Raised );
-	setFocusPolicy( TQ_NoFocus );
+	setFocusPolicy( TQWidget::NoFocus );
 
 	setMouseTracking( true );
 
@@ -705,7 +705,7 @@ void KMdiChildFrm::setIcon( const TQPixmap& pxm )
 	if ( p.width() != 18 || p.height() != 18 )
 	{
 		TQImage img = p.convertToImage();
-		p = img.smoothScale( 18, 18, TQ_ScaleMin );
+		p = img.smoothScale( 18, 18, TQImage::ScaleMin );
 	}
 	const bool do_resize = m_pIconButtonPixmap->size() != p.size();
 	*m_pIconButtonPixmap = p;
@@ -750,9 +750,9 @@ void KMdiChildFrm::setClient( KMdiChildView *w, bool bAutomaticResize )
 	}
 
 	// memorize the focuses in a dictionary because they will get lost during reparenting
-	TQDict<TQ_FocusPolicy>* pFocPolDict = new TQDict<TQ_FocusPolicy>;
+	TQDict<TQWidget::FocusPolicy>* pFocPolDict = new TQDict<TQWidget::FocusPolicy>;
 	pFocPolDict->setAutoDelete( true );
-	TQObjectList *list = m_pClient->queryList( TQWIDGET_OBJECT_NAME_STRING );
+	TQObjectList *list = m_pClient->queryList( "TQWidget" );
 	TQObjectListIt it( *list );          // iterate over the buttons
 	TQObject * obj;
 	int i = 1;
@@ -768,14 +768,14 @@ void KMdiChildFrm::setClient( KMdiChildView *w, bool bAutomaticResize )
 			widg->setName( tmpStr.latin1() );
 			i++;
 		}
-		TQ_FocusPolicy* pFocPol = new TQ_FocusPolicy;
+		TQWidget::FocusPolicy* pFocPol = new TQWidget::FocusPolicy;
 		*pFocPol = widg->focusPolicy();
 		pFocPolDict->insert( widg->name(), pFocPol );
 	}
 	delete list;                        // delete the list, not the objects
 
 	//Reparent if needed
-	if ( TQT_BASE_OBJECT(w->parent()) != TQT_BASE_OBJECT(this) )
+	if ( w->parent() != this )
 	{
 		//reparent to this widget , no flags , point , show it
 		TQPoint pnt2( KMDI_CHILDFRM_BORDER, clientYPos );
@@ -817,7 +817,7 @@ void KMdiChildFrm::unsetClient( TQPoint positionOffset )
 	TQObject::disconnect( m_pClient, TQT_SIGNAL( mdiParentNowMaximized( bool ) ), m_pManager, TQT_SIGNAL( nowMaximized( bool ) ) );
 
 	//reparent to desktop widget , no flags , point , show it
-	TQDict<TQ_FocusPolicy>* pFocPolDict;
+	TQDict<TQWidget::FocusPolicy>* pFocPolDict;
 	pFocPolDict = unlinkChildren();
 
 	// get name of focused child widget
@@ -833,7 +833,7 @@ void KMdiChildFrm::unsetClient( TQPoint positionOffset )
 	m_pClient->setMaximumSize( maxs.width(), maxs.height() );
 
 	// remember the focus policies using the dictionary and reset them
-	TQObjectList *list = m_pClient->queryList( TQWIDGET_OBJECT_NAME_STRING );
+	TQObjectList *list = m_pClient->queryList( "TQWidget" );
 	TQObjectListIt it( *list );          // iterate over all child widgets of child frame
 	TQObject * obj;
 	TQWidget* firstFocusableChildWidget = 0;
@@ -842,7 +842,7 @@ void KMdiChildFrm::unsetClient( TQPoint positionOffset )
 	{ // for each found object...
 		TQWidget * widg = ( TQWidget* ) obj;
 		++it;
-		TQ_FocusPolicy* pFocPol = pFocPolDict->find( widg->name() ); // remember the focus policy from before the reparent
+		TQWidget::FocusPolicy* pFocPol = pFocPolDict->find( widg->name() ); // remember the focus policy from before the reparent
 		if ( pFocPol )
 			widg->setFocusPolicy( *pFocPol );
 		
@@ -851,7 +851,7 @@ void KMdiChildFrm::unsetClient( TQPoint positionOffset )
 			widg->setFocus();
 
 		// get first and last focusable widget
-		if ( ( widg->focusPolicy() == TQ_StrongFocus ) || ( widg->focusPolicy() == TQ_TabFocus ) )
+		if ( ( widg->focusPolicy() == TQWidget::StrongFocus ) || ( widg->focusPolicy() == TQWidget::TabFocus ) )
 		{
 			if ( firstFocusableChildWidget == 0 )
 				firstFocusableChildWidget = widg;  // first widget
@@ -860,7 +860,7 @@ void KMdiChildFrm::unsetClient( TQPoint positionOffset )
 		}
 		else
 		{
-			if ( widg->focusPolicy() == TQ_WheelFocus )
+			if ( widg->focusPolicy() == TQWidget::WheelFocus )
 			{
 				if ( firstFocusableChildWidget == 0 )
 					firstFocusableChildWidget = widg;  // first widget
@@ -877,29 +877,29 @@ void KMdiChildFrm::unsetClient( TQPoint positionOffset )
 	m_pClient->setLastFocusableChildWidget( lastFocusableChildWidget );
 
 	// reset the focus policy of the view
-	m_pClient->setFocusPolicy( TQ_ClickFocus );
+	m_pClient->setFocusPolicy( TQWidget::ClickFocus );
 
 	// lose information about the view (because it's undocked now)
 	m_pClient = 0;
 }
 
 //============== linkChildren =============//
-void KMdiChildFrm::linkChildren( TQDict<TQ_FocusPolicy>* pFocPolDict )
+void KMdiChildFrm::linkChildren( TQDict<TQWidget::FocusPolicy>* pFocPolDict )
 {
 	// reset the focus policies for all widgets in the view (take them from the dictionary)
-	TQObjectList* list = m_pClient->queryList( TQWIDGET_OBJECT_NAME_STRING );
+	TQObjectList* list = m_pClient->queryList( "TQWidget" );
 	TQObjectListIt it( *list );          // iterate over all child widgets of child frame
 	TQObject* obj;
 	while ( ( obj = it.current() ) != 0 )
 	{ // for each found object...
 		TQWidget* widg = ( TQWidget* ) obj;
 		++it;
-		TQ_FocusPolicy* pFocPol = pFocPolDict->find( widg->name() ); // remember the focus policy from before the reparent
+		TQWidget::FocusPolicy* pFocPol = pFocPolDict->find( widg->name() ); // remember the focus policy from before the reparent
 		
 		if ( pFocPol != 0 )
 			widg->setFocusPolicy( *pFocPol );
 		
-		if ( !( widg->inherits( TQPOPUPMENU_OBJECT_NAME_STRING ) ) )
+		if ( !( widg->inherits( "TQPopupMenu" ) ) )
 			widg->installEventFilter( this );
 
 	}
@@ -907,14 +907,14 @@ void KMdiChildFrm::linkChildren( TQDict<TQ_FocusPolicy>* pFocPolDict )
 	delete pFocPolDict;
 
 	// reset the focus policies for the rest
-	m_pWinIcon->setFocusPolicy( TQ_NoFocus );
-	m_pUnixIcon->setFocusPolicy( TQ_NoFocus );
-	m_pClient->setFocusPolicy( TQ_ClickFocus );
-	m_pCaption->setFocusPolicy( TQ_NoFocus );
-	m_pUndock->setFocusPolicy( TQ_NoFocus );
-	m_pMinimize->setFocusPolicy( TQ_NoFocus );
-	m_pMaximize->setFocusPolicy( TQ_NoFocus );
-	m_pClose->setFocusPolicy( TQ_NoFocus );
+	m_pWinIcon->setFocusPolicy( TQWidget::NoFocus );
+	m_pUnixIcon->setFocusPolicy( TQWidget::NoFocus );
+	m_pClient->setFocusPolicy( TQWidget::ClickFocus );
+	m_pCaption->setFocusPolicy( TQWidget::NoFocus );
+	m_pUndock->setFocusPolicy( TQWidget::NoFocus );
+	m_pMinimize->setFocusPolicy( TQWidget::NoFocus );
+	m_pMaximize->setFocusPolicy( TQWidget::NoFocus );
+	m_pClose->setFocusPolicy( TQWidget::NoFocus );
 
 	// install the event filter (catch mouse clicks) for the rest
 	m_pWinIcon->installEventFilter( this );
@@ -930,13 +930,13 @@ void KMdiChildFrm::linkChildren( TQDict<TQ_FocusPolicy>* pFocPolDict )
 
 //============== unlinkChildren =============//
 
-TQDict<TQ_FocusPolicy>* KMdiChildFrm::unlinkChildren()
+TQDict<TQWidget::FocusPolicy>* KMdiChildFrm::unlinkChildren()
 {
 	// memorize the focuses in a dictionary because they will get lost during reparenting
-	TQDict<TQ_FocusPolicy>* pFocPolDict = new TQDict<TQ_FocusPolicy>;
+	TQDict<TQWidget::FocusPolicy>* pFocPolDict = new TQDict<TQWidget::FocusPolicy>;
 	pFocPolDict->setAutoDelete( true );
 
-	TQObjectList *list = m_pClient->queryList( TQWIDGET_OBJECT_NAME_STRING );
+	TQObjectList *list = m_pClient->queryList( "TQWidget" );
 	TQObjectListIt it( *list );          // iterate over all child widgets of child frame
 	TQObject * obj;
 	int i = 1;
@@ -953,7 +953,7 @@ TQDict<TQ_FocusPolicy>* KMdiChildFrm::unlinkChildren()
 			w->setName( tmpStr.latin1() );
 			i++;
 		}
-		TQ_FocusPolicy* pFocPol = new TQ_FocusPolicy;
+		TQWidget::FocusPolicy* pFocPol = new TQWidget::FocusPolicy;
 		*pFocPol = w->focusPolicy();
 		// memorize focus policy
 		pFocPolDict->insert( w->name(), pFocPol );
@@ -1085,7 +1085,7 @@ bool KMdiChildFrm::eventFilter( TQObject *obj, TQEvent *e )
 			TQObject* pObj = obj;
 			while ( ( pObj != 0L ) && !bIsChild )
 			{
-				bIsChild = ( TQT_BASE_OBJECT(pObj) == TQT_BASE_OBJECT(this) );
+				bIsChild = ( pObj == this );
 				pObj = pObj->parent();
 			}
 			// unset the resize cursor if the cursor moved from the frame into a inner widget
@@ -1101,7 +1101,7 @@ bool KMdiChildFrm::eventFilter( TQObject *obj, TQEvent *e )
 				if ( m_timeMeasure.elapsed() <= TQApplication::doubleClickInterval() )
 					bIsSecondClick = true;  // of a possible double click
 
-				if ( !( ( ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(m_pWinIcon) ) || ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(m_pUnixIcon) ) ) && bIsSecondClick ) )
+				if ( !( ( ( obj == m_pWinIcon ) || ( obj == m_pUnixIcon ) ) && bIsSecondClick ) )
 				{
 					// in case we didn't click on the icon button
 					TQFocusEvent focusEvent( TQFocusEvent::FocusIn );
@@ -1112,16 +1112,16 @@ bool KMdiChildFrm::eventFilter( TQObject *obj, TQEvent *e )
 						m_pClient->activate();
 					}
 					
-					if ( ( TQT_BASE_OBJECT(obj->parent()) != TQT_BASE_OBJECT(m_pCaption) ) && ( TQT_BASE_OBJECT(obj) != TQT_BASE_OBJECT(m_pCaption) ) )
+					if ( ( obj->parent() != m_pCaption ) && ( obj != m_pCaption ) )
 					{
 						TQWidget* w = ( TQWidget* ) obj;
-						if ( ( w->focusPolicy() == TQ_ClickFocus ) || ( w->focusPolicy() == TQ_StrongFocus ) )
+						if ( ( w->focusPolicy() == TQWidget::ClickFocus ) || ( w->focusPolicy() == TQWidget::StrongFocus ) )
 						{
 							w->setFocus();
 						}
 					}
 				}
-				if ( ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(m_pWinIcon) ) || ( TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(m_pUnixIcon) ) )
+				if ( ( obj == m_pWinIcon ) || ( obj == m_pUnixIcon ) )
 				{
 					// in case we clicked on the icon button
 					if ( m_timeMeasure.elapsed() > TQApplication::doubleClickInterval() )
@@ -1155,7 +1155,7 @@ bool KMdiChildFrm::eventFilter( TQObject *obj, TQEvent *e )
 			// if we lost a child we uninstall ourself as event filter for the lost
 			// child and its children
 			TQObject* pLostChild = TQT_TQOBJECT(( ( TQChildEvent* ) e )->child());
-			if ( ( pLostChild != 0L )   /*&& (pLostChild->inherits(TQWIDGET_OBJECT_NAME_STRING))*/ )
+			if ( ( pLostChild != 0L )   /*&& (pLostChild->inherits("TQWidget"))*/ )
 			{
 				TQObjectList* list = pLostChild->queryList();
 				list->insert( 0, pLostChild );        // add the lost child to the list too, just to save code
@@ -1180,7 +1180,7 @@ bool KMdiChildFrm::eventFilter( TQObject *obj, TQEvent *e )
 			if ( ( pNewChild != 0L ) && ::tqqt_cast<TQWidget*>( pNewChild ) )
 			{
 				TQWidget * pNewWidget = TQT_TQWIDGET( pNewChild );
-				TQObjectList *list = pNewWidget->queryList( TQWIDGET_OBJECT_NAME_STRING );
+				TQObjectList *list = pNewWidget->queryList( "TQWidget" );
 				list->insert( 0, pNewChild );         // add the new child to the list too, just to save code
 				TQObjectListIt it( *list );          // iterate over all new child widgets
 				TQObject * obj;
