@@ -439,7 +439,7 @@ int DownloadDialog::installStatus(Entry *entry)
   if(datestring.isNull()) installed = 0;
   else
   {
-    date = TQT_TQDATE_OBJECT(TQDate::fromString(datestring, Qt::ISODate));
+    date = TQDate::fromString(datestring, Qt::ISODate);
     if(!date.isValid()) installed = 0;
     else if(date < entry->releaseDate()) installed = -1;
     else installed = 1;
