@@ -208,7 +208,7 @@ bool PartManager::eventFilter( TQObject *obj, TQEvent *ev )
     if ( !d->m_managedTopLevelWidgets.containsRef( w->topLevelWidget() ) )
       return false;
 
-    if ( d->m_bIgnoreScrollBars && w->inherits( TQSCROLLBAR_OBJECT_NAME_STRING ) )
+    if ( d->m_bIgnoreScrollBars && w->inherits( "TQScrollBar" ) )
       return false;
 
     if ( mev ) // mouse press or mouse double-click event
@@ -351,11 +351,11 @@ void PartManager::addPart( Part *part, bool setActive )
   }
 
   // Prevent focus problems
-  if ( part->widget() && part->widget()->focusPolicy() == TQ_NoFocus )
+  if ( part->widget() && part->widget()->focusPolicy() == TQWidget::NoFocus )
   {
     kdWarning(1000) << "Part '" << part->name() << "' has a widget " << part->widget()->name() << " with a focus policy of NoFocus. It should have at least a ClickFocus policy, for part activation to work well." << endl;
   }
-  if ( part->widget() && part->widget()->focusPolicy() == TQ_TabFocus )
+  if ( part->widget() && part->widget()->focusPolicy() == TQWidget::TabFocus )
   {
     kdWarning(1000) << "Part '" << part->name() << "' has a widget " << part->widget()->name() << " with a focus policy of TabFocus. It should have at least a ClickFocus policy, for part activation to work well." << endl;
   }
