@@ -48,7 +48,7 @@ class PartManagerPrivate;
  */
 class TDEPARTS_EXPORT PartManager : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   TQ_ENUMS( SelectionPolicy )
   TQ_PROPERTY( SelectionPolicy selectionPolicy READ selectionPolicy WRITE setSelectionPolicy )
   TQ_PROPERTY( bool allowNestedParts READ allowNestedParts WRITE setAllowNestedParts )
