@@ -28,7 +28,7 @@ class TQPushButton;
 
 class KMWDriverSelect : public KMWizardPage
 {
-	Q_OBJECT
+	TQ_OBJECT
 public:
 	KMWDriverSelect(TQWidget *parent = 0, const char *name = 0);
 
