@@ -33,7 +33,7 @@ using KSpell2::Dictionary;
 
 class ISpellClient : public KSpell2::Client
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     ISpellClient( TQObject *parent, const char *name, const TQStringList & /* args */  );
     ~ISpellClient();
