@@ -97,7 +97,7 @@ AsteroidStyle::~AsteroidStyle()
 
 void AsteroidStyle::polish(const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, void *ptr)
 {
-	if (ceData.widgetObjectTypes.contains(TQWIDGET_OBJECT_NAME_STRING)) {
+	if (ceData.widgetObjectTypes.contains("TQWidget")) {
 		TQWidget *w = reinterpret_cast<TQWidget*>(ptr);
 /*		Screwing with the palette is fun! and required in order to make it feel
 		authentic. -clee */
@@ -124,7 +124,7 @@ void AsteroidStyle::polish(const TQStyleControlElementData &ceData, ControlEleme
 		}
 	}
 
-	if (ceData.widgetObjectTypes.contains(TQPUSHBUTTON_OBJECT_NAME_STRING)) {
+	if (ceData.widgetObjectTypes.contains("TQPushButton")) {
 		installObjectEventHandler(ceData, elementFlags, ptr, this);
 	}
 	else {
@@ -283,7 +283,7 @@ void AsteroidStyle::drawTDEStylePrimitive(TDEStylePrimitive ksp,
 	}
 }
 
-int AsteroidStyle::styleHint( TQ_StyleHint stylehint,
+int AsteroidStyle::styleHint( StyleHint stylehint,
                                    const TQStyleControlElementData &ceData,
                                    ControlElementFlags elementFlags,
                                    const TQStyleOption &option,
@@ -313,7 +313,7 @@ int AsteroidStyle::styleHint( TQ_StyleHint stylehint,
 	}
 }
 
-void AsteroidStyle::drawPrimitive(TQ_PrimitiveElement pe,
+void AsteroidStyle::drawPrimitive(PrimitiveElement pe,
                                   TQPainter *p,
                                   const TQStyleControlElementData &ceData,
                                   ControlElementFlags elementFlags,
@@ -1985,7 +1985,7 @@ void AsteroidStyle::drawComplexControl(TQ_ComplexControl cc,
 			p->drawRect(hr);
 
 			bool draw_skinny_frame = false;
-// 			if (!ceData.widgetObjectTypes.contains(TQCOMBOBOX_OBJECT_NAME_STRING)) draw_skinny_frame = true;
+// 			if (!ceData.widgetObjectTypes.contains("TQComboBox")) draw_skinny_frame = true;
 			if (ceData.comboBoxListBoxFlags & CEF_IsVisible) draw_skinny_frame = true;
 			if (draw_skinny_frame) {
 				p->setPen(cg.mid());
@@ -2289,7 +2289,7 @@ int AsteroidStyle::pixelMetric(PixelMetric pm, const TQStyleControlElementData &
 		}
 
 		case PM_DefaultFrameWidth: {
-			if (ceData.widgetObjectTypes.contains(TQPOPUPMENU_OBJECT_NAME_STRING)) {
+			if (ceData.widgetObjectTypes.contains("TQPopupMenu")) {
 				return 3;
 			} else {
 				return TDEStyle::pixelMetric(pm, ceData, elementFlags, w);
@@ -2618,7 +2618,7 @@ bool AsteroidStyle::objectEventHandler( const TQStyleControlElementData &ceData,
 	/*	Win2K has this interesting behaviour where it sets the current
 		default button to whatever pushbutton the user presses the mouse
 		on. I _think_ this emulates that properly. -clee */
-	if (ceData.widgetObjectTypes.contains(TQPUSHBUTTON_OBJECT_NAME_STRING)) {
+	if (ceData.widgetObjectTypes.contains("TQPushButton")) {
 		if (e->type() == TQEvent::MouseButtonPress) {
 			widgetActionRequest(ceData, elementFlags, source, WAR_SetDefault);
 		}
