@@ -154,14 +154,14 @@ void HighContrastStyle::polish( TQPalette& pal )
 
 void HighContrastStyle::polish (const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, void *ptr)
 {
-	if (ceData.widgetObjectTypes.contains(TQWIDGET_OBJECT_NAME_STRING)) {
+	if (ceData.widgetObjectTypes.contains("TQWidget")) {
 		TQWidget *widget = reinterpret_cast<TQWidget*>(ptr);
 
-		if (widget->inherits (TQBUTTON_OBJECT_NAME_STRING)
-			|| widget->inherits (TQCOMBOBOX_OBJECT_NAME_STRING)
-			|| widget->inherits (TQSPINWIDGET_OBJECT_NAME_STRING)
-			|| widget->inherits (TQLINEEDIT_OBJECT_NAME_STRING)
-			|| widget->inherits (TQTEXTEDIT_OBJECT_NAME_STRING))
+		if (widget->inherits ("TQButton")
+			|| widget->inherits ("TQComboBox")
+			|| widget->inherits ("TQSpinWidget")
+			|| widget->inherits ("TQLineEdit")
+			|| widget->inherits ("TQTextEdit"))
 		{
 			installObjectEventHandler(ceData, elementFlags, ptr, this);
 	
@@ -181,9 +181,9 @@ void HighContrastStyle::polish (const TQStyleControlElementData &ceData, Control
 
 void HighContrastStyle::unPolish (const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, void *ptr)
 {
-	if (ceData.widgetObjectTypes.contains(TQWIDGET_OBJECT_NAME_STRING)) {
+	if (ceData.widgetObjectTypes.contains("TQWidget")) {
 		TQWidget *widget = reinterpret_cast<TQWidget*>(ptr);
-		if (widget->inherits (TQWIDGET_OBJECT_NAME_STRING) || widget->inherits (TQCOMBOBOX_OBJECT_NAME_STRING) || widget->inherits (TQSPINWIDGET_OBJECT_NAME_STRING) || widget->inherits (TQLINEEDIT_OBJECT_NAME_STRING) || widget->inherits (TQTEXTEDIT_OBJECT_NAME_STRING)) {
+		if (widget->inherits ("TQWidget") || widget->inherits ("TQComboBox") || widget->inherits ("TQSpinWidget") || widget->inherits ("TQLineEdit") || widget->inherits ("TQTextEdit")) {
 			installObjectEventHandler(ceData, elementFlags, ptr, this);
 		}
 	}
@@ -286,7 +286,7 @@ void HighContrastStyle::drawEllipse (TQPainter* p, TQRect r, int offset, bool fi
 	p->drawRoundRect (r, 99, 99);
 }
 
-void HighContrastStyle::drawArrow (TQPainter* p, TQRect r, TQ_PrimitiveElement arrow, int offset) const
+void HighContrastStyle::drawArrow (TQPainter* p, TQRect r, PrimitiveElement arrow, int offset) const
 {
 	p->save();
 	addOffset (&r, offset);
@@ -337,7 +337,7 @@ void HighContrastStyle::drawArrow (TQPainter* p, TQRect r, TQ_PrimitiveElement a
 }
 
 // This function draws primitive elements
-void HighContrastStyle::drawPrimitive (TQ_PrimitiveElement pe,
+void HighContrastStyle::drawPrimitive (PrimitiveElement pe,
 								TQPainter *p,
 								const TQStyleControlElementData &ceData,
 								ControlElementFlags elementFlags,
@@ -724,7 +724,7 @@ void HighContrastStyle::drawTDEStylePrimitive (TDEStylePrimitive kpe,
 		case KPE_SliderGroove: {
 			setColorsText (p, cg, flags);
 			TQRect r2 (r);
-			if (ceData.widgetObjectTypes.contains(TQSLIDER_OBJECT_NAME_STRING))
+			if (ceData.widgetObjectTypes.contains("TQSlider"))
 			{
 				if (ceData.orientation == TQt::Horizontal)
 				{
@@ -764,7 +764,7 @@ void HighContrastStyle::drawTDEStylePrimitive (TDEStylePrimitive kpe,
 			// Probably it would be better to add a KPM_ListViewExpander metric
 			// to the TDEStyle TDEStylePixelMetric enum, and have the TDEStyle
 			// drawComplexControl handle it.
-			TQ_PrimitiveElement direction;
+			PrimitiveElement direction;
 			if (flags & Style_On) { // Collapsed = On
 				direction = PE_ArrowRight;
 
@@ -1146,7 +1146,7 @@ void HighContrastStyle::drawControl (TQ_ControlElement element,
 
 			// Does the menu item have a submenu?
 			if ( mi->popup() ) {
-				TQ_PrimitiveElement arrow = reverse ? PE_ArrowLeft : PE_ArrowRight;
+				PrimitiveElement arrow = reverse ? PE_ArrowLeft : PE_ArrowRight;
 				int dim = pixelMetric(PM_MenuButtonIndicator, ceData, elementFlags);
 				TQRect vr = visualRect( TQRect( x + w - arrowHMargin - 2*itemFrame - dim,
 							y + h / 2 - dim / 2, dim, dim), r );
@@ -1622,7 +1622,7 @@ int HighContrastStyle::pixelMetric(PixelMetric m, const TQStyleControlElementDat
 		}
 
 		case PM_DefaultFrameWidth: {
-			if (widget && (ceData.widgetObjectTypes.contains (TQLINEEDIT_OBJECT_NAME_STRING) || ceData.widgetObjectTypes.contains (TQTEXTEDIT_OBJECT_NAME_STRING)))
+			if (widget && (ceData.widgetObjectTypes.contains ("TQLineEdit") || ceData.widgetObjectTypes.contains ("TQTextEdit")))
 				return 2*basicLineWidth;
 			else 
 				return basicLineWidth;
