@@ -212,7 +212,7 @@ static void drawLightBevel( TQPainter *p,
 	p->fillRect( br, *fill );
 }
 
-void LightStyleV3::drawPrimitive( TQ_PrimitiveElement pe,
+void LightStyleV3::drawPrimitive( PrimitiveElement pe,
 				TQPainter *p,
 				const TQStyleControlElementData &ceData,
 				ControlElementFlags elementFlags,
@@ -430,7 +430,7 @@ void LightStyleV3::drawPrimitive( TQ_PrimitiveElement pe,
 	    if ( p && p->device()->devType() == TQInternal::Widget ) {
 		TQWidget *w = (TQWidget *) p->device();
 		TQWidget *p = w->parentWidget();
-		if (p->inherits(TQDOCKWINDOW_OBJECT_NAME_STRING) && ! p->inherits(TQTOOLBAR_OBJECT_NAME_STRING)) {
+		if (p->inherits("TQDockWindow") && ! p->inherits("TQToolBar")) {
 		    drawTitle = true;
 		    title = p->caption();
 		}
@@ -590,7 +590,7 @@ void LightStyleV3::drawPrimitive( TQ_PrimitiveElement pe,
     case PE_ScrollBarSubLine:
 	{
 	    TQRect br = r;
-	    TQ_PrimitiveElement pe;
+	    PrimitiveElement pe;
 
 	    p->setPen( cg.background() );
 	    if (flags & Style_Horizontal) {
@@ -624,7 +624,7 @@ void LightStyleV3::drawPrimitive( TQ_PrimitiveElement pe,
     case PE_ScrollBarAddLine:
 	{
 	    TQRect br = r;
-	    TQ_PrimitiveElement pe;
+	    PrimitiveElement pe;
 
 	    p->setPen( cg.background() );
 	    if (flags & Style_Horizontal) {
@@ -1257,7 +1257,7 @@ void LightStyleV3::drawComplexControl( TQ_ComplexControl control,
 		drawPrimitive( PE_Panel, p, ceData, elementFlags, frame, cg, flags | Style_Sunken );
 
 	    if ((controls & SC_SpinWidgetUp) && up.isValid()) {
-		TQ_PrimitiveElement pe = PE_SpinWidgetUp;
+		PrimitiveElement pe = PE_SpinWidgetUp;
 		if ( ceData.spinWidgetData.buttonSymbols == TQSpinWidget::PlusMinus )
 		    pe = PE_SpinWidgetPlus;
 
@@ -1275,7 +1275,7 @@ void LightStyleV3::drawComplexControl( TQ_ComplexControl control,
 	    }
 
 	    if ((controls & SC_SpinWidgetDown) && down.isValid()) {
-		TQ_PrimitiveElement pe = PE_SpinWidgetDown;
+		PrimitiveElement pe = PE_SpinWidgetDown;
 		if ( ceData.spinWidgetData.buttonSymbols == TQSpinWidget::PlusMinus )
 		    pe = PE_SpinWidgetMinus;
 
@@ -1854,7 +1854,7 @@ TQSize LightStyleV3::sizeFromContents( ContentsType contents,
     return ret;
 }
 
-int LightStyleV3::styleHint( TQ_StyleHint stylehint,
+int LightStyleV3::styleHint( StyleHint stylehint,
 			   const TQStyleControlElementData &ceData,
 			   ControlElementFlags elementFlags,
 			   const TQStyleOption &option,
