@@ -122,7 +122,7 @@ KBugReport::KBugReport( TQWidget * parentw, bool modal, const TDEAboutData *abou
                                         parent );
     connect( m_configureEmail, TQT_SIGNAL( clicked() ), this,
              TQT_SLOT( slotConfigureEmail() ) );
-    glay->addMultiCellWidget( m_configureEmail, 0, 2, 2, 2, (TQ_Alignment)(AlignTop|AlignRight) );
+    glay->addMultiCellWidget( m_configureEmail, 0, 2, 2, 2, (Qt::AlignmentFlags)(AlignTop|AlignRight) );
 
     // To
     qwtstr = i18n( "The email address this bug report is sent to." );
@@ -241,7 +241,7 @@ KBugReport::KBugReport( TQWidget * parentw, bool modal, const TDEAboutData *abou
     lay->addWidget( label );
 
     // The multiline-edit
-    m_lineedit = new TQMultiLineEdit( parent, TQMULTILINEEDIT_OBJECT_NAME_STRING );
+    m_lineedit = new TQMultiLineEdit( parent, "TQMultiLineEdit" );
     m_lineedit->setMinimumHeight( 180 ); // make it big
     m_lineedit->setWordWrap(TQMultiLineEdit::WidgetWidth);
     lay->addWidget( m_lineedit, 10 /*stretch*/ );
