@@ -64,7 +64,10 @@
 #include <config.h>
 #include <kdebug.h>
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #ifdef Q_WS_X11
 #include <X11/Xlib.h> 
 
@@ -295,7 +298,7 @@ void KValueSelector::drawPalette( TQPixmap *pixmap )
 	TQImage image( xSize, ySize, 32 );
 	TQColor col;
 	uint *p;
-	QRgb rgb;
+	TQRgb rgb;
 
 	if ( orientation() == Qt::Horizontal )
 	{
@@ -626,9 +629,6 @@ static const char * const *namedColorFilePath( void )
 #ifdef X11_RGBFILE
     X11_RGBFILE,
 #endif
-	"/usr/share/X11/rgb.txt",
-    "/usr/X11R6/lib/X11/rgb.txt",
-    "/usr/openwin/lib/X11/rgb.txt", // for Solaris.
     0
   };
   return path;
@@ -1187,7 +1187,7 @@ KColorDialog::~KColorDialog()
 bool
 KColorDialog::eventFilter( TQObject *obj, TQEvent *ev )
 {
-    if ((TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(d->htmlName)) || (TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(d->hsSelector)))
+    if ((obj == d->htmlName) || (obj == d->hsSelector))
     switch(ev->type())
     {
       case TQEvent::DragEnter:
