@@ -124,7 +124,7 @@ KDateTable::KDateTable(TQWidget *parent, TQDate date_, const char* name, WFlags
       kdDebug() << "KDateTable ctor: WARNING: Given date is invalid, using current date." << endl;
       date_=TQDate::currentDate();
     }
-  setFocusPolicy( TQ_StrongFocus );
+  setFocusPolicy( TQWidget::StrongFocus );
   setNumRows(7); // 6 weeks max + headline
   setNumCols(7); // 7 days a week
   setHScrollBarMode(AlwaysOff);
@@ -140,7 +140,7 @@ KDateTable::KDateTable(TQWidget *parent, const char* name, WFlags f)
 {
   d = new KDateTablePrivate;
   setFontSize(10);
-  setFocusPolicy( TQ_StrongFocus );
+  setFocusPolicy( TQWidget::StrongFocus );
   setNumRows(7); // 6 weeks max + headline
   setNumCols(7); // 7 days a week
   setHScrollBarMode(AlwaysOff);
@@ -351,22 +351,22 @@ void KDateTable::previousMonth()
 
 void KDateTable::beginningOfMonth()
 {
-  setDate(TQT_TQDATE_OBJECT(date.addDays(1 - date.day())));
+  setDate(date.addDays(1 - date.day()));
 }
 
 void KDateTable::endOfMonth()
 {
-  setDate(TQT_TQDATE_OBJECT(date.addDays(date.daysInMonth() - date.day())));
+  setDate(date.addDays(date.daysInMonth() - date.day()));
 }
 
 void KDateTable::beginningOfWeek()
 {
-  setDate(TQT_TQDATE_OBJECT(date.addDays(1 - date.dayOfWeek())));
+  setDate(date.addDays(1 - date.dayOfWeek()));
 }
 
 void KDateTable::endOfWeek()
 {
-  setDate(TQT_TQDATE_OBJECT(date.addDays(7 - date.dayOfWeek())));
+  setDate(date.addDays(7 - date.dayOfWeek()));
 }
 
 void
@@ -374,22 +374,22 @@ KDateTable::keyPressEvent( TQKeyEvent *e )
 {
     switch( e->key() ) {
     case Key_Up:
-            setDate(TQT_TQDATE_OBJECT(date.addDays(-7)));
+            setDate(date.addDays(-7));
         break;
     case Key_Down:
-            setDate(TQT_TQDATE_OBJECT(date.addDays(7)));
+            setDate(date.addDays(7));
         break;
     case Key_Left:
-            setDate(TQT_TQDATE_OBJECT(date.addDays(-1)));
+            setDate(date.addDays(-1));
         break;
     case Key_Right:
-            setDate(TQT_TQDATE_OBJECT(date.addDays(1)));
+            setDate(date.addDays(1));
         break;
     case Key_Minus:
-        setDate(TQT_TQDATE_OBJECT(date.addDays(-1)));
+        setDate(date.addDays(-1));
 	break;
     case Key_Plus:
-        setDate(TQT_TQDATE_OBJECT(date.addDays(1)));
+        setDate(date.addDays(1));
 	break;
     case Key_N:
         setDate(TQDate::currentDate());
@@ -447,7 +447,7 @@ KDateTable::setFontSize(int size)
 void
 KDateTable::wheelEvent ( TQWheelEvent * e )
 {
-    setDate(TQT_TQDATE_OBJECT(date.addMonths( -(int)(e->delta()/120)) ));
+    setDate(date.addMonths( -(int)(e->delta()/120)) );
     e->accept();
 }
 
