@@ -37,7 +37,7 @@
    - KDockWidget                   - IMPORTANT CLASS: the one and only dockwidget class
    - KDockManager                  - helper class
    - KDockMainWindow               - IMPORTANT CLASS: a special TDEMainWindow that can have dockwidgets
-   - KDockArea                     - like KDockMainWindow but inherits just QWidget
+   - KDockArea                     - like KDockMainWindow but inherits just TQWidget
 
    IMPORTANT Note: This file compiles also in Qt-only mode by using the NO_KDE2 precompiler definition!
 */
@@ -102,7 +102,7 @@ namespace KMDI
  */
 class TDEUI_EXPORT KDockWidgetAbstractHeader : public TQFrame
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
 
@@ -152,7 +152,7 @@ private:
  */
 class TDEUI_EXPORT KDockWidgetAbstractHeaderDrag : public TQFrame
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
 
@@ -198,7 +198,7 @@ private:
  */
 class TDEUI_EXPORT KDockWidgetHeaderDrag : public KDockWidgetAbstractHeaderDrag
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
 
@@ -240,7 +240,7 @@ private:
  */
 class TDEUI_EXPORT KDockWidgetHeader : public KDockWidgetAbstractHeader
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
 
@@ -366,7 +366,7 @@ private:
  */
 class TDEUI_EXPORT KDockTabGroup : public TQTabWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   /**
@@ -427,7 +427,7 @@ private:
  */
 class TDEUI_EXPORT KDockWidget: public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 friend class KDockManager;
 friend class KDockSplitter;
@@ -914,7 +914,7 @@ private:
  */
 class TDEUI_EXPORT KDockManager: public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 friend class KDockWidget;
 friend class KDockMainWindow;
@@ -1313,7 +1313,7 @@ private:
  */
 class TDEUI_EXPORT KDockMainWindow : public TDEMainWindow
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 friend class KDockManager;
@@ -1484,7 +1484,7 @@ private:
 
 class TDEUI_EXPORT KDockArea : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 friend class KDockManager;
