@@ -31,7 +31,7 @@
  */
 class KDE_DEPRECATED KDockWindow : public KSystemTray
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     KDockWindow( TQWidget* parent = 0, const char* name  = 0 )
 	: KSystemTray( parent, name ) {}
