@@ -1006,7 +1006,7 @@ void KLineEdit::dropEvent(TQDropEvent *e)
 
 bool KLineEdit::eventFilter( TQObject* o, TQEvent* ev )
 {
-    if( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) )
+    if( o == this )
     {
         KCursor::autoHideEventFilter( TQT_TQOBJECT(this), ev );
         if ( ev->type() == TQEvent::AccelOverride )
@@ -1092,8 +1092,6 @@ void KLineEdit::setCompletionBox( TDECompletionBox *box )
                  TQT_SLOT(setTextWorkaround( const TQString& )) );
         connect( d->completionBox, TQT_SIGNAL(userCancelled( const TQString& )),
                  TQT_SLOT(userCancelled( const TQString& )) );
-
-        // TODO: we need our own slot, and to call setModified(true) if Qt4 has that.
         connect( d->completionBox, TQT_SIGNAL( activated( const TQString& )),
                  TQT_SIGNAL(completionBoxActivated( const TQString& )) );
     }
