@@ -32,7 +32,6 @@
 #include <tqwhatsthis.h>
 #include <tqptrdict.h>
 #include <tqtimer.h>
-#include <tqtextcodec.h>
 
 #include <tdeglobal.h>
 #include <kdebug.h>
@@ -138,12 +137,8 @@ KPasswordEdit::~KPasswordEdit()
 {
 }
 
-const char *KPasswordEdit::password() const {
-    TQTextCodec *origCStringCodec = TQTextCodec::codecForCStrings();
-    TQTextCodec::setCodecForCStrings(TQTextCodec::codecForLocale());
-    const char *outputPassword = text().ascii();
-    TQTextCodec::setCodecForCStrings(origCStringCodec);
-    return outputPassword;
+TQString KPasswordEdit::password() const {
+    return text();
 }
 
 void KPasswordEdit::erase()
@@ -235,12 +230,12 @@ void KPasswordDialog::init()
 	lbl->setPixmap(pix);
 	lbl->setAlignment(AlignHCenter|AlignVCenter);
 	lbl->setFixedSize(lbl->sizeHint());
-	m_pGrid->addWidget(lbl, 0, 0, (TQ_Alignment)AlignCenter);
+	m_pGrid->addWidget(lbl, 0, 0, (Qt::AlignmentFlags)AlignCenter);
     }
 
     m_pHelpLbl = new TQLabel(m_pMain);
     m_pHelpLbl->setAlignment(AlignLeft|AlignVCenter|WordBreak);
-    m_pGrid->addWidget(m_pHelpLbl, 0, 2, (TQ_Alignment)AlignLeft);
+    m_pGrid->addWidget(m_pHelpLbl, 0, 2, (Qt::AlignmentFlags)AlignLeft);
     m_pGrid->addRowSpacing(1, 10);
     m_pGrid->setRowStretch(1, 12);
 
@@ -253,7 +248,7 @@ void KPasswordDialog::init()
     lbl->setAlignment(AlignLeft|AlignVCenter);
     lbl->setText(i18n("&Password:"));
     lbl->setFixedSize(lbl->sizeHint());
-    m_pGrid->addWidget(lbl, 7, 0, (TQ_Alignment)AlignLeft);
+    m_pGrid->addWidget(lbl, 7, 0, (Qt::AlignmentFlags)AlignLeft);
 
     TQHBoxLayout *h_lay = new TQHBoxLayout();
     m_pGrid->addLayout(h_lay, 7, 2);
@@ -283,8 +278,8 @@ void KPasswordDialog::init()
 	    m_keepWarnLbl->hide();
 	}
 	connect(cb, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotKeep(bool)));
-	m_pGrid->addWidget(cb, 9, 2, (TQ_Alignment)(AlignLeft|AlignVCenter));
-//	m_pGrid->addWidget(m_keepWarnLbl, 13, 2, (TQ_Alignment)(AlignLeft|AlignVCenter));
+	m_pGrid->addWidget(cb, 9, 2, (Qt::AlignmentFlags)(AlignLeft|AlignVCenter));
+//	m_pGrid->addWidget(m_keepWarnLbl, 13, 2, (Qt::AlignmentFlags)(AlignLeft|AlignVCenter));
 	m_pGrid->addMultiCellWidget(m_keepWarnLbl, 13, 13, 0, 3);
     } else if (m_Type == NewPassword) {
 	m_pGrid->addRowSpacing(8, 10);
@@ -292,7 +287,7 @@ void KPasswordDialog::init()
 	lbl->setAlignment(AlignLeft|AlignVCenter);
 	lbl->setText(i18n("&Verify:"));
 	lbl->setFixedSize(lbl->sizeHint());
-	m_pGrid->addWidget(lbl, 9, 0, (TQ_Alignment)AlignLeft);
+	m_pGrid->addWidget(lbl, 9, 0, (Qt::AlignmentFlags)AlignLeft);
 
 	h_lay = new TQHBoxLayout();
 	m_pGrid->addLayout(h_lay, 9, 2);
@@ -386,12 +381,12 @@ void KPasswordDialog::addLine(TQString key, TQString value)
     TQLabel *lbl = new TQLabel(key, m_pMain);
     lbl->setAlignment(AlignLeft|AlignTop);
     lbl->setFixedSize(lbl->sizeHint());
-    m_pGrid->addWidget(lbl, m_Row+2, 0, (TQ_Alignment)AlignLeft);
+    m_pGrid->addWidget(lbl, m_Row+2, 0, (Qt::AlignmentFlags)AlignLeft);
 
     lbl = new TQLabel(value, m_pMain);
     lbl->setAlignment(AlignTop|WordBreak);
     lbl->setFixedSize(275, lbl->heightForWidth(275));
-    m_pGrid->addWidget(lbl, m_Row+2, 2, (TQ_Alignment)AlignLeft);
+    m_pGrid->addWidget(lbl, m_Row+2, 2, (Qt::AlignmentFlags)AlignLeft);
     ++m_Row;
 }
 
@@ -408,7 +403,7 @@ void KPasswordDialog::erase()
 void KPasswordDialog::slotOk()
 {
     if (m_Type == NewPassword) {
-	if (strcmp(m_pEdit->password(), m_pEdit2->password())) {
+	if (m_pEdit->password() != m_pEdit2->password()) {
 	    KMessageBox::sorry(this, i18n("You entered two different "
 		    "passwords. Please try again."));
 	    erase();
@@ -463,8 +458,7 @@ void KPasswordDialog::slotLayout()
 }
 
 
-// static . antlarr: KDE 4: Make it const TQString & prompt
-int KPasswordDialog::getPassword(TQCString &password, TQString prompt,
+int KPasswordDialog::getPassword(TQString &password, TQString prompt,
 	int *keep)
 {
     const bool enableKeep = (keep && *keep);
@@ -481,7 +475,7 @@ int KPasswordDialog::getPassword(TQCString &password, TQString prompt,
 
 
 // static . antlarr: KDE 4: Make it const TQString & prompt
-int KPasswordDialog::getNewPassword(TQCString &password, TQString prompt)
+int KPasswordDialog::getNewPassword(TQString &password, TQString prompt)
 {
     KPasswordDialog* const dlg = new KPasswordDialog(NewPassword, prompt);
     const int ret = dlg->exec();
@@ -506,8 +500,8 @@ void KPasswordDialog::virtual_hook( int id, void* data )
 void KPasswordDialog::enableOkBtn()
 {
     if (m_Type == NewPassword) {
-      const bool match = strcmp(m_pEdit->password(), m_pEdit2->password()) == 0
-                   && (d->allowEmptyPasswords || m_pEdit->password()[0]);
+      const bool match = (m_pEdit->password() == m_pEdit2->password())
+                   && (d->allowEmptyPasswords || !m_pEdit->password().isEmpty());
 
       const TQString pass(m_pEdit->password());
 
@@ -519,7 +513,7 @@ void KPasswordDialog::enableOkBtn()
           enableButtonOK( match );
       }
 
-      if ( match && d->allowEmptyPasswords && m_pEdit->password()[0] == 0 ) {
+      if ( match && d->allowEmptyPasswords && m_pEdit->password().isEmpty() ) {
           d->m_MatchLabel->setText( i18n("Password is empty") );
       } else {
           if ((int) pass.length() < minPasswordLength) {
