@@ -45,7 +45,7 @@ class KRootPixmapData;
  */
 class TDEUI_EXPORT KRootPixmap: public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     /**
