@@ -34,7 +34,7 @@ class KTabBarPrivate;
  */
 class TDEUI_EXPORT KTabBar: public TQTabBar
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     KTabBar( TQWidget* parent=0, const char* name=0 );
