@@ -61,7 +61,7 @@ class BuildHelper;
 class TDEUI_EXPORT KXMLGUIFactory : public TQObject
 {
   friend class KXMLGUI::BuildHelper;
-  Q_OBJECT
+  TQ_OBJECT
  public:
   /**
    * Constructs a KXMLGUIFactory. The provided @p builder KXMLGUIBuilder will be called
