@@ -322,12 +322,12 @@ void TDERadioAction::slotActivated()
 {
   if ( isChecked() )
   {
-    const TQObject *senderObj = TQT_TQOBJECT_CONST(sender());
+    const TQObject *senderObj = sender();
 
     if ( !senderObj || !::tqqt_cast<const TDEToolBarButton *>( senderObj ) )
       return;
 
-    const_cast<TDEToolBarButton *>( static_cast<const TDEToolBarButton *>( TQT_TQWIDGET_CONST(senderObj) ) )->on( true );
+    const_cast<TDEToolBarButton *>( static_cast<const TDEToolBarButton *>( senderObj ) )->on( true );
 
     return;
   }
@@ -677,7 +677,7 @@ int TDESelectAction::plug( TQWidget *widget, int index )
     TQComboBox *cb = bar->getCombo( id_ );
     if ( cb )
     {
-      if (!isEditable()) cb->setFocusPolicy(TQ_NoFocus);
+      if (!isEditable()) cb->setFocusPolicy(TQWidget::NoFocus);
       cb->setMinimumWidth( cb->sizeHint().width() );
       if ( d->m_comboWidth > 0 )
       {
@@ -2103,7 +2103,7 @@ void TDEToggleFullScreenAction::setChecked( bool c )
 
 bool TDEToggleFullScreenAction::eventFilter( TQObject* o, TQEvent* e )
 {
-    if( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(window) )
+    if( o == window )
         if( e->type() == TQEvent::WindowStateChange )
             {
             if( window->isFullScreen() != isChecked())
