@@ -547,7 +547,7 @@ void TDEActionCollection::slotMenuItemHighlighted( int id )
   if ( d->m_currentHighlightAction )
     emit actionHighlighted( d->m_currentHighlightAction, false );
 
-  TQWidget *container = const_cast<TQWidget*>(TQT_TQWIDGET_CONST( sender() ));
+  TQWidget *container = static_cast<TQWidget *>( const_cast<TQObject *>( sender() ));
 
   d->m_currentHighlightAction = findAction( container, id );
 
@@ -581,7 +581,7 @@ void TDEActionCollection::slotToolBarButtonHighlighted( int id, bool highlight )
   if ( !d->m_highlight )
     return;
 
-  TQWidget *container = const_cast<TQWidget*>(TQT_TQWIDGET_CONST( sender() ));
+  TQWidget *container = static_cast<TQWidget *>( const_cast<TQObject *>( sender() ));
 
   TDEAction *action = findAction( container, id );
 
@@ -606,7 +606,7 @@ void TDEActionCollection::slotToolBarButtonHighlighted( int id, bool highlight )
 
 void TDEActionCollection::slotDestroyed()
 {
-    d->m_dctHighlightContainers.remove( reinterpret_cast<void *>( const_cast<TQObject*>(TQT_TQOBJECT_CONST(sender())) ) );
+    d->m_dctHighlightContainers.remove( reinterpret_cast<void *>( const_cast<TQObject*>(sender()) ) );
 }
 
 TDEAction *TDEActionCollection::findAction( TQWidget *container, int id )
