@@ -98,7 +98,7 @@ class DCOPObject;
 class TDEUI_EXPORT TDEMainWindow : public TQMainWindow, public KXMLGUIBuilder, virtual public KXMLGUIClient
 {
     friend class KMWSessionManaged;
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     /**
