@@ -21,10 +21,6 @@
 #include <tqtimer.h>
 #include <tqfontmetrics.h>
 
-#ifdef USE_QT4
-#undef None
-#endif // USE_QT4
-
 #include <tqstyle.h>
 
 #include "tdepopupmenu.h"
