@@ -57,7 +57,7 @@ class TDEToolBarPrivate;
 
 class TDEUI_EXPORT TDEToolBarSeparator : public TQFrame
 {
-    Q_OBJECT
+    TQ_OBJECT
     
 public:
     TDEToolBarSeparator( Orientation, bool l, TQToolBar *parent, const char* name=0 );
@@ -103,7 +103,7 @@ private:
 
 class TDEUI_EXPORT TDEToolBar : public TQToolBar
 {
-    Q_OBJECT
+    TQ_OBJECT
     
     TQ_ENUMS( IconText BarPosition )
     TQ_PROPERTY( IconText iconText READ iconText WRITE setIconText )
@@ -645,7 +645,7 @@ public:
    * You can do with this whatever you want,
    * except change its height (hardcoded). If you change its width
    * you will probably have to call TQToolBar::updateRects(true)
-   * @see QWidget
+   * @see TQWidget
    * @see updateRects()
    */
     TQWidget *getWidget (int id); // ### KDE4: make this const!
