@@ -13,7 +13,7 @@
 
 class KDesatWidget : public TQWidget
 {
-Q_OBJECT
+TQ_OBJECT
 public:
     KDesatWidget(TQWidget *parent=0, const char *name=0);
 
