@@ -10,7 +10,7 @@ class TQMultiLineEdit;
 
 class testWindow  : public TDEMainWindow
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     testWindow (TQWidget *parent=0, const char *name=0);
