@@ -30,7 +30,7 @@ private:
 
 class myTopWidget: public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
 public:
   myTopWidget(TQWidget *parent=0, const char *name=0);
   
