@@ -463,7 +463,7 @@ TQSize KMultiTabBarButton::sizeHint() const
     int w = 0, h = 0;
 
     // calculate contents size...
-#ifndef QT_NO_ICONSET
+#ifndef TQT_NO_ICONSET
     if ( iconSet() && !iconSet()->isNull() ) {
         int iw = iconSet()->pixmap( TQIconSet::Small, TQIconSet::Normal ).width() + 4;
         int ih = iconSet()->pixmap( TQIconSet::Small, TQIconSet::Normal ).height();
